@@ -4,31 +4,8 @@ declare(strict_types=1);
 
 
 /**
- * Circles - Bring cloud-users closer together.
- *
- * This file is licensed under the Affero General Public License version 3 or
- * later. See the COPYING file.
- *
- * @author Maxence Lange <maxence@artificial-owl.com>
- * @author Vinicius Cubas Brand <vinicius@eita.org.br>
- * @author Daniel Tygel <dtygel@eita.org.br>
- *
- * @copyright 2017
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 
@@ -58,6 +35,7 @@ use OCA\Circles\Exceptions\UnknownRemoteException;
 use OCA\Circles\FederatedItems\Files\FileShare;
 use OCA\Circles\FederatedItems\Files\FileUnshare;
 use OCA\Circles\Model\Federated\FederatedEvent;
+use OCA\Circles\Model\Member;
 use OCA\Circles\Model\Probes\CircleProbe;
 use OCA\Circles\Model\Probes\DataProbe;
 use OCA\Circles\Model\ShareWrapper;
@@ -65,6 +43,7 @@ use OCA\Circles\Service\CircleService;
 use OCA\Circles\Service\EventService;
 use OCA\Circles\Service\FederatedEventService;
 use OCA\Circles\Service\FederatedUserService;
+use OCA\Circles\Service\ShareTokenService;
 use OCA\Circles\Service\ShareWrapperService;
 use OCA\Circles\Tools\Traits\TArrayTools;
 use OCA\Circles\Tools\Traits\TNCLogger;
@@ -107,6 +86,7 @@ class ShareByCircleProvider implements IShareProvider {
 	private LoggerInterface $logger;
 	private IURLGenerator $urlGenerator;
 	private ShareWrapperService $shareWrapperService;
+	private ShareTokenService $shareTokenService;
 	private FederatedUserService $federatedUserService;
 	private FederatedEventService $federatedEventService;
 	private CircleService $circleService;
@@ -130,6 +110,7 @@ class ShareByCircleProvider implements IShareProvider {
 		$this->federatedUserService = OC::$server->get(FederatedUserService::class);
 		$this->federatedEventService = OC::$server->get(FederatedEventService::class);
 		$this->shareWrapperService = OC::$server->get(ShareWrapperService::class);
+		$this->shareTokenService = OC::$server->get(ShareTokenService::class);
 		$this->circleService = OC::$server->get(CircleService::class);
 		$this->eventService = OC::$server->get(EventService::class);
 	}
@@ -179,7 +160,7 @@ class ShareByCircleProvider implements IShareProvider {
 		try {
 			$knowShareWrapper = $this->shareWrapperService->searchShare($share->getSharedWith(), $nodeId);
 			throw new AlreadySharedException(
-				$this->l10n->t('This item is already shared with this circle'),
+				$this->l10n->t('This item is already shared with this team'),
 				$knowShareWrapper->getShare($this->rootFolder, $this->userManager, $this->urlGenerator)
 			);
 		} catch (ShareWrapperNotFoundException $e) {
@@ -225,8 +206,11 @@ class ShareByCircleProvider implements IShareProvider {
 	public function update(IShare $share): IShare {
 		$wrappedShare = $this->shareWrapperService->getShareById((int)$share->getId());
 		$wrappedShare->setPermissions($share->getPermissions())
-					 ->setShareOwner($share->getShareOwner())
-					 ->setSharedBy($share->getSharedBy());
+			->setShareOwner($share->getShareOwner())
+			->setAttributes($share->getAttributes())
+			->setSharedBy($share->getSharedBy())
+			->setExpirationDate($share->getExpirationDate())
+			->setShareNote($share->getNote());
 
 		$this->shareWrapperService->update($wrappedShare);
 
@@ -401,6 +385,11 @@ class ShareByCircleProvider implements IShareProvider {
 			if ($wrappedShare->getFileCache()->isAccessible()) {
 				$result[$wrappedShare->getFileSource()][] =
 					$wrappedShare->getShare($this->rootFolder, $this->userManager, $this->urlGenerator);
+			} else {
+				$this->logger->debug('shared document is not available anymore', ['wrappedShare' => $wrappedShare]);
+				if ($wrappedShare->getFileCache()->getPath() === '') {
+					$this->logger->notice('share is not available while path is empty. might comes from an unsupported storage.', ['wrappedShare' => $wrappedShare]);
+				}
 			}
 		}
 
@@ -437,7 +426,7 @@ class ShareByCircleProvider implements IShareProvider {
 		$nodeId = (!is_null($node)) ? $node->getId() : 0;
 
 		try {
-			$federatedUser = $this->federatedUserService->getLocalFederatedUser($userId, false);
+			$federatedUser = $this->federatedUserService->getLocalFederatedUser($userId);
 		} catch (Exception $e) {
 			$this->e($e, ['userId' => $userId, 'shareType' => $shareType, 'nodeId' => $nodeId]);
 
@@ -641,15 +630,168 @@ class ShareByCircleProvider implements IShareProvider {
 
 
 	/**
+	 * if $currentAccess, returns long version of the access list:
+	 * [
+	 *   'users'  => [
+	 *     'user1' => ['node_id' => 42, 'node_path' => '/fileA'],
+	 *     'user4' => ['node_id' => 32, 'node_path' => '/folder2'],
+	 *     'user2' => ['node_id' => 23, 'node_path' => '/folder (1)'],
+	 *   ],
+	 *   'remote' => [
+	 *     'user1@server1' => ['node_id' => 42, 'token' => 'SeCr3t'],
+	 *     'user2@server2' => ['node_id' => 23, 'token' => 'FooBaR'],
+	 *   ],
+	 *   'public' => bool,
+	 *   'mail' => [
+	 *     'email1@maildomain1' => ['node_id' => 42, 'token' => 'aBcDeFg'],
+	 *     'email2@maildomain2' => ['node_id' => 23, 'token' => 'hIjKlMn'],
+	 *   ]
+	 * ]
+	 *
+	 *
+	 *
+	 *
 	 * @param Node[] $nodes
 	 * @param bool $currentAccess
 	 *
 	 * @return array
 	 */
 	public function getAccessList($nodes, $currentAccess): array {
-		return [];
+		$ids = [];
+		foreach ($nodes as $node) {
+			$ids[] = $node->getId();
+		}
+
+
+		if (!$currentAccess) {
+			return $this->getAccessListShort($ids);
+		}
+
+		$shareIds = $knownIds = $users = $remote = $mails = [];
+		foreach ($this->shareWrapperService->getSharesByFileIds($ids, true, true) as $share) {
+			if (!$share->hasCircle()) {
+				continue;
+			}
+
+			$shareIds[] = $share->getId();
+			$circle = $share->getCircle();
+			foreach ($circle->getInheritedMembers() as $member) {
+				if ($share->getParent() > 0 && in_array($member->getSingleId(), $knownIds[$share->getFileSource()] ?? [])) {
+					continue;
+				}
+				$knownIds[$share->getFileSource()][] = $member->getSingleId();
+
+				switch ($member->getUserType()) {
+					case Member::TYPE_USER:
+						if ($member->isLocal()) {
+							$users[$member->getUserId()] = [
+								'node_id' => $share->getFileSource(),
+								'node_path' => $share->getFileTarget()
+							];
+						} else {
+							// we only store temp value, as token is unknown at this point
+							$remote[$member->getUserid() . '@' . $member->getInstance()] = [
+								'node_id' => $share->getFileSource(),
+								'shareId' => $share->getId(),
+								'memberId' => $member->getId(),
+							];
+						}
+						break;
+					case Member::TYPE_MAIL:
+						// we only store temp value, as token is unknown at this point
+						$mails[$member->getUserId()] = [
+							'node_id' => $share->getFileSource(),
+							'shareId' => $share->getId(),
+							'memberId' => $member->getId(),
+						];
+						break;
+				}
+			}
+		}
+
+		// list share tokens in an indexed array and update details for remote/mail entries with the correct token
+		$shareTokens = [];
+		foreach ($this->shareTokenService->getTokensFromShares(array_values(array_unique($shareIds))) as $shareToken) {
+			$shareTokens[$shareToken->getShareId()][$shareToken->getMemberId()] = $shareToken->getToken();
+		}
+
+		return [
+			'users' => $users,
+			'remote' => $this->updateAccessListTokens($remote, $shareTokens),
+			'email' => $this->updateAccessListTokens($mails, $shareTokens)
+		];
 	}
 
+	/**
+	 * returns short version of the access list:
+	 * [
+	 *   'users'  => ['user1', 'user2', 'user4'],
+	 *   'remote' => bool,
+	 *   'mail' => ['email1@maildomain1', 'email2@maildomain2']
+	 * ]
+	 *
+	 * @param array $ids
+	 *
+	 * @return array
+	 * @throws FederatedItemException
+	 * @throws RemoteInstanceException
+	 * @throws RemoteNotFoundException
+	 * @throws RemoteResourceNotFoundException
+	 * @throws RequestBuilderException
+	 * @throws UnknownRemoteException
+	 */
+	private function getAccessListShort(array $ids): array {
+		$users = $mails = [];
+		$remote = false;
+		foreach ($this->shareWrapperService->getSharesByFileIds($ids, true) as $share) {
+			if (!$share->hasCircle()) {
+				continue;
+			}
+			$circle = $share->getCircle();
+			foreach ($circle->getInheritedMembers() as $member) {
+				switch ($member->getUserType()) {
+					case Member::TYPE_USER:
+						if ($member->isLocal()) {
+							if (!in_array($member->getUserId(), $users)) {
+								$users[] = $member->getUserId();
+							}
+						} else {
+							$remote = true;
+						}
+						break;
+					case Member::TYPE_MAIL:
+						if (!in_array($member->getUserId(), $mails)) {
+							$mails[] = $member->getUserId();
+						}
+						break;
+				}
+			}
+		}
+
+		return [
+			'users' => $users,
+			'remote' => $remote,
+			'email' => $mails
+		];
+	}
+
+	/**
+	 * @param array $list
+	 * @param array<int, array<string, string>> $shareTokens
+	 *
+	 * @return array
+	 */
+	private function updateAccessListTokens(array $list, array $shareTokens): array {
+		$result = [];
+		foreach($list as $id => $data) {
+			$result[$id] = [
+				'node_id' => $data['node_id'],
+				'token' => $shareTokens[$data['shareId']][$data['memberId']]
+			];
+		}
+
+		return $result;
+	}
 
 	/**
 	 * We don't return a thing about children.
@@ -669,26 +811,26 @@ class ShareByCircleProvider implements IShareProvider {
 	 * @return iterable
 	 */
 	public function getAllShares(): iterable {
-//		$qb = $this->dbConnection->getQueryBuilder();
-//
-//		$qb->select(' * ')
-//		   ->from('share')
-//		   ->where(
-//			   $qb->expr()
-//				  ->orX(
-//					  $qb->expr()
-//						 ->eq('share_type', $qb->createNamedParameter(IShare::TYPE_CIRCLE))
-//				  )
-//		   );
-//
-//		$cursor = $qb->execute();
-//		while ($data = $cursor->fetch()) {
-//			try {
-//				yield $this->createShareObject($data);
-//			} catch (IllegalIDChangeException $e) {
-//			};
-//		}
-//		$cursor->closeCursor();
+		//		$qb = $this->dbConnection->getQueryBuilder();
+		//
+		//		$qb->select(' * ')
+		//		   ->from('share')
+		//		   ->where(
+		//			   $qb->expr()
+		//				  ->orX(
+		//					  $qb->expr()
+		//						 ->eq('share_type', $qb->createNamedParameter(IShare::TYPE_CIRCLE))
+		//				  )
+		//		   );
+		//
+		//		$cursor = $qb->execute();
+		//		while ($data = $cursor->fetch()) {
+		//			try {
+		//				yield $this->createShareObject($data);
+		//			} catch (IllegalIDChangeException $e) {
+		//			};
+		//		}
+		//		$cursor->closeCursor();
 		return [];
 	}
 }
