@@ -1,117 +1,6 @@
 OC.L10N.register(
     "files",
     {
-    "File could not be found" : "No fue posible encontrar el archivo",
-    "Move or copy" : "Mover o copiar",
-    "Download" : "Descargar",
-    "Delete" : "Borrar",
-    "Tags" : "Etiquetas",
-    "Show list view" : "Mostrar vista de lista",
-    "Show grid view" : "Mostrar vista de cuadrícula",
-    "Home" : "Inicio",
-    "Close" : "Cerrar",
-    "Could not create folder \"{dir}\"" : "No fue posible crear la carpeta \"{dir}\"",
-    "This will stop your current uploads." : "Esto detendrá tus cargas actuales.",
-    "Upload cancelled." : "Carga cancelada.",
-    "Processing files …" : "Procesando archivos...",
-    "…" : "...",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No fue posible cargar {filename} ya que es una carpeta o tiene un tamaño de 0 bytes",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No tienes suficiente espacio disponible, Estás cargando {size1} pero sólo cuentas con {size2} disponible",
-    "Target folder \"{dir}\" does not exist any more" : "La carpeta destino \"{dir}\" ya no existe",
-    "Not enough free space" : "No cuentas con suficiente espacio libre",
-    "An unknown error has occurred" : "Ha ocurrido un error desconocido.",
-    "File could not be uploaded" : "No se pudo cargar el archivo.",
-    "Uploading …" : "Cargando...",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "No se admite la carga de ese elemento.",
-    "Target folder does not exist any more" : "La carpeta destino ya no existe",
-    "Operation is blocked by access control" : "La operación está bloqueada por el control de acceso.",
-    "Error when assembling chunks, status code {status}" : "Se presentó un error al ensamblar los bloques, código de estatus {status}",
-    "Actions" : "Acciones",
-    "Rename" : "Renombrar",
-    "Move" : "Mover",
-    "Copy" : "Copiar",
-    "Choose target folder" : "Selecciona la carpeta de destino.",
-    "Edit locally" : "Editar localmente.",
-    "Open" : "Abrir",
-    "Delete file" : "Borrar archivo",
-    "Delete folder" : "Borrar carpeta",
-    "Disconnect storage" : "Desconectar almacenamiento",
-    "Leave this share" : "Salir de esta compartición.",
-    "Could not load info for file \"{file}\"" : "No fue posible cargar información para el archivo \"{file}\"",
-    "Files" : "Archivos",
-    "Details" : "Detalles",
-    "Please select tag(s) to add to the selection" : "Selecciona la(s) etiqueta(s) para agregar a la selección.",
-    "Apply tag(s) to selection" : "Aplicar etiqueta(s) a la selección.",
-    "Select directory \"{dirName}\"" : "Selecciona el directorio \"{dirName}\".",
-    "Select file \"{fileName}\"" : "Selecciona el archivo \"{fileName}\".",
-    "Pending" : "Pendiente",
-    "Unable to determine date" : "No fue posible determinar la fecha",
-    "This operation is forbidden" : "Esta operación está prohibida",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verfica las bitácoras o contacta al administrador",
-    "Storage is temporarily not available" : "El almacenamiento no está disponible temporalmente ",
-    "Could not move \"{file}\", target exists" : "No fue posible mover \"{file}\", el destino ya existe",
-    "Could not move \"{file}\"" : "No fue posible mover \"{file}\"",
-    "copy" : "copia",
-    "Could not copy \"{file}\", target exists" : "No se pudo copiar \"{file}\", el destino ya existe",
-    "Could not copy \"{file}\"" : "No se pudo copiar \"{file}\"",
-    "Copied {origin} inside {destination}" : "{origin} fue copiado dentro de {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} y otros {nbfiles} archivos fueron copiados dentro de {destination}",
-    "Failed to redirect to client" : "No se pudo redirigir al cliente.",
-    "{newName} already exists" : "{newName} ya existe",
-    "Could not rename \"{fileName}\", it does not exist any more" : "No fue posible renombrar \"{fileName}\", ya no existe",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nombre \"{targetName}\" ya está en uso en la carpeta \"{dir}\". Por favor elege un nombre diferete. ",
-    "Could not rename \"{fileName}\"" : "No fue posible renombrar \"{fileName}\"",
-    "Could not create file \"{file}\"" : "No fue posible crear el archivo \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "No fue posible crear el archivo\"{file}\" porque ya existe",
-    "Could not create folder \"{dir}\" because it already exists" : "No fue posible crear la carpeta \"{dir}\" porque ya existe",
-    "Could not fetch file details \"{file}\"" : "No se pudieron obtener los detalles del archivo \"{file}\".",
-    "Error deleting file \"{fileName}\"." : "Se presentó un error al borrar el archivo \"{fileName}\".",
-    "No search results in other folders for {tag}{filter}{endtag}" : "No se encontraron resultados en otras carpetas para  {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Ingresa más de dos caracteres para buscar en otras carpetas.",
-    "Name" : "Nombre",
-    "Size" : "Tamaño",
-    "Modified" : "Modificado",
-    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas","%n carpetas"],
-    "_%n file_::_%n files_" : ["%n archivo","%n archivos","%n archivos"],
-    "{dirs} and {files}" : "{dirs} y {files}",
-    "_including %n hidden_::_including %n hidden_" : ["incluyendo %n oculto","incluyendo %n ocultos","incluyendo %n ocultos"],
-    "You do not have permission to upload or create files here" : "No tienes permiso para cargar o crear archivos aquí.",
-    "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Cargando %n archivos","Cargando %n archivos"],
-    "New" : "Nuevo",
-    "New file/folder menu" : "Menú de archivo/carpeta nuevo.",
-    "Select file range" : "Selecciona un rango de archivos.",
-    "{used}%" : "{used}%",
-    "{used} of {quota} used" : "{used} de {quota} usados",
-    "{used} used" : "{used} usados",
-    "\"{name}\" is an invalid file name." : "\"{name}\" es un nombre de archivo inválido. ",
-    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
-    "\"/\" is not allowed inside a file name." : "No se permite el uso del caracter \"/\" en el nombre del archivo.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" es un tipo de archivo no permitido",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "El almacenamiento de {owner} está lleno, no se pueden actualizar ni sincronizar archivos.",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "La carpeta de grupo \"{mountPoint}\" está llena, no se pueden actualizar ni sincronizar archivos.",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "El almacenamiento externo \"{mountPoint}\" está lleno, no se pueden actualizar ni sincronizar archivos.",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Tu almacenamiento está lleno, no se pueden actualizar ni sincronizar archivos.",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "El almacenamiento de {owner} está casi lleno ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "La carpeta de grupo \"{mountPoint}\" está casi llena ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "El almacenamiento externo \"{mountPoint}\" está casi lleno ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Tu almacenamiento está casi lleno ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["coincide con \"{filter}\".","coincide con \"{filter}\".","coincide con \"{filter}\"."],
-    "View in folder" : "Ver en la carpeta",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Se ha copiado el enlace directo (solo funciona para usuarios que tienen acceso a este archivo/carpeta).",
-    "Path" : "Ruta",
-    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
-    "Favorited" : "Marcado como favorito",
-    "Favorite" : "Favorito",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar liga directa (sólo funciona para usuarios que tienen acceso a este archivo/carpeta)",
-    "New folder" : "Carpeta nueva",
-    "Create new folder" : "Crear nueva carpeta",
-    "Upload file" : "Cargar archivo",
-    "Recent" : "Reciente",
-    "Not favorited" : "No es un favorito",
-    "Remove from favorites" : "Eliminar de favoritos",
-    "Add to favorites" : "Agregar a favoritos",
-    "An error occurred while trying to update the tags" : "Se presentó un error al intentar actualizar la etiqueta",
     "Added to favorites" : "Agregado a los favoritos",
     "Removed from favorites" : "Eliminado de los favoritos",
     "You added {file} to your favorites" : "Agregaste {file} a tus favoritos",
@@ -124,7 +13,6 @@ OC.L10N.register(
     "Restored by {user}" : "Restaurado por {user}",
     "Renamed by {user}" : "Renombrado por {user}",
     "Moved by {user}" : "Movido por {user}",
-    "\"remote user\"" : "\"usuario remoto\"",
     "You created {file}" : "Creaste {file}",
     "You created an encrypted file in {file}" : "Creaste un archivo encriptado en {file}",
     "{user} created {file}" : "{user} creó {file}",
@@ -151,8 +39,10 @@ OC.L10N.register(
     "You moved {oldfile} to {newfile}" : "Moviste {oldfile} a {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} movió {oldfile} a {newfile}",
     "A file has been added to or removed from your <strong>favorites</strong>" : "Un archivo ha sido agregado o eliminado de tus <strong>favoritos</strong>",
+    "Files" : "Archivos",
     "A file or folder has been <strong>changed</strong>" : "Un archivo o carpeta ha sido <strong>modificado</strong>.",
     "A favorite file or folder has been <strong>changed</strong>" : "Un archivo o carpeta favorito ha sido <strong>modificado</strong>.",
+    "No favorites" : "No hay favoritos",
     "Upload (max. %s)" : "Cargar (max. %s)",
     "Accept" : "Aceptar",
     "Reject" : "Rechazar",
@@ -166,35 +56,38 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "La transferencia de propiedad de {path} de {user} se ha completado.",
     "in %s" : "en %s",
     "File Management" : "Gestión de archivos.",
+    "Home" : "Inicio",
+    "Target folder does not exist any more" : "La carpeta destino ya no existe",
     "Reload current directory" : "Recargar directorio actual.",
     "Go to the \"{dir}\" directory" : "Ir al directorio \"{dir}\".",
-    "You don’t have permission to upload or create files here" : "No cuentas con los permisos para cargar o crear archivos aquí",
-    "\"{displayName}\" action executed successfully" : "La acción \"{displayName}\" se ejecutó correctamente.",
-    "\"{displayName}\" action failed" : "La acción \"{displayName}\" falló.",
-    "Rename file" : "Renombrar archivo.",
-    "File name" : "Nombre de archivo.",
+    "Favorite" : "Favorito",
+    "Filename" : "Nombre de archivo",
     "Folder name" : "Nombre de la carpeta",
-    "Download file {name}" : "Descargar archivo {name}.",
-    "\"{name}\" is not an allowed filetype." : "\"{name}\" no es un tipo de archivo permitido.",
-    "{newName} already exists." : "{newName} ya existe.",
-    "Name cannot be empty" : "El nombre no puede estar en blanco",
-    "Another entry with the same name already exists" : "Ya existe otra entrada con el mismo nombre.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Cambiaste el nombre de \"{oldName}\" a \"{newName}\".",
-    "Could not rename \"{oldName}\", it does not exist any more" : "No se pudo cambiar el nombre de \"{oldName}\", ya no existe.",
-    "Could not rename \"{oldName}\"" : "No se pudo cambiar el nombre de \"{oldName}\".",
+    "Rename file" : "Renombrar archivo.",
+    "Folder" : "Carpeta",
+    "Pending" : "Pendiente",
+    "Clear filter" : "Borrar filtro",
+    "Modified" : "Modificado",
+    "Type" : "Tipo",
+    "Active filters" : "Filtros activos",
+    "Remove filter" : "Eliminar filtro",
     "Total rows summary" : "Resumen total de filas.",
-    "\"{displayName}\" failed on some elements " : "La acción \"{displayName}\" falló en algunos elementos.",
+    "Name" : "Nombre",
+    "Size" : "Tamaño",
     "\"{displayName}\" batch action executed successfully" : "La acción en lote \"{displayName}\" se ejecutó correctamente.",
+    "\"{displayName}\" action failed" : "La acción \"{displayName}\" falló.",
+    "Actions" : "Acciones",
     "List of files and folders." : "Lista de archivos y carpetas. ",
-    "Storage informations" : "Información de almacenamiento.",
     "{usedQuotaByte} used" : "{usedQuotaByte} usados.",
+    "{used} of {quota} used" : "{used} de {quota} usados",
     "{relative}% used" : "{relative}% usados.",
     "Could not refresh storage stats" : "No se pudo actualizar las estadísticas de almacenamiento.",
     "Your storage is full, files can not be updated or synced anymore!" : "Tu espacio está lleno. ¡Los archivos ya no se pueden actualizar o sincronizar!",
-    "Transfer ownership of a file or folder" : "Transferir propiedad de un archivo o carpeta.",
-    "Choose file or folder to transfer" : "Selecciona un archivo o carpeta para transferir.",
-    "Change" : "Cambiar",
-    "New owner" : "Nuevo propietario.",
+    "New folder" : "Carpeta nueva",
+    "Create new folder" : "Crear nueva carpeta",
+    "Create" : "Crear",
+    "Submit" : "Enviar",
     "Choose a file or folder to transfer" : "Elige un archivo o carpeta para transferir.",
     "Transfer" : "Transferencia",
     "Transfer {path} to {userid}" : "Transferir {path} a {userid}.",
@@ -202,19 +95,28 @@ OC.L10N.register(
     "Unknown error" : "Se presentó un error desconocido",
     "Ownership transfer request sent" : "Solicitud de transferencia de propiedad enviada.",
     "Cannot transfer ownership of a file or folder you do not own" : "No se puede transferir la propiedad de un archivo o carpeta que no posees.",
+    "Transfer ownership of a file or folder" : "Transferir propiedad de un archivo o carpeta.",
+    "Choose file or folder to transfer" : "Selecciona un archivo o carpeta para transferir.",
+    "Change" : "Cambiar",
+    "New owner" : "Nuevo propietario.",
     "Select file or folder to link to" : "Seleccionar archivo o carpeta para enlazar.",
-    "Add" : "Guardar",
-    "Loading current folder" : "Cargando directorio actual.",
-    "No files in here" : "No hay archivos aquí",
-    "Upload some content or sync with your devices!" : "¡Carga algún contenido o sincroniza con tus dispositivos!",
-    "Go to the previous folder" : "Ir a la carpeta anterior.",
-    "Go back" : "Regresar",
     "Shared by link" : "Compartido por liga",
     "Shared" : "Compartido",
     "Switch to list view" : "Cambiar a vista de lista",
-    "Open the files app settings" : "Abrir la configuración de la aplicación de archivos.",
+    "Not enough free space" : "No cuentas con suficiente espacio libre",
+    "Operation is blocked by access control" : "La operación está bloqueada por el control de acceso.",
+    "\"{displayName}\" action executed successfully" : "La acción \"{displayName}\" se ejecutó correctamente.",
+    "Loading current folder" : "Cargando directorio actual.",
+    "Retry" : "Reintentar",
+    "No files in here" : "No hay archivos aquí",
+    "Upload some content or sync with your devices!" : "¡Carga algún contenido o sincroniza con tus dispositivos!",
+    "Go back" : "Regresar",
+    "Views" : "Vistas",
     "Files settings" : "Configuración de archivos.",
+    "Open in files" : "Abrir en archivos",
     "File cannot be accessed" : "No se puede acceder al archivo.",
+    "Clipboard is not available" : "El portapapeles no está disponible",
+    "WebDAV URL copied to clipboard" : "URL de WebDAV copiada al portapapeles.",
     "Sort favorites first" : "Ordenar primero los favoritos.",
     "Show hidden files" : "Mostrar archivos ocultos",
     "Crop image previews" : "Recortar vistas previas de imágenes.",
@@ -223,56 +125,139 @@ OC.L10N.register(
     "Copy to clipboard" : "Copiar al portapapeles",
     "Use this address to access your Files via WebDAV" : "Usa esta dirección para acceder a tus archivos a través de WebDAV.",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si has habilitado la autenticación de dos factores (2FA), debes crear y usar una nueva contraseña de aplicación haciendo clic aquí.",
-    "Clipboard is not available" : "El portapapeles no está disponible",
-    "WebDAV URL copied to clipboard" : "URL de WebDAV copiada al portapapeles.",
-    "Unable to change the favourite state of the file" : "No se puede cambiar el estado de favorito del archivo.",
+    "Keyboard shortcuts" : "Atajos del teclado",
+    "Selection" : "Selección",
+    "Navigation" : "Navegación",
+    "View" : "Ver",
     "Error while loading the file data" : "Error al cargar los datos del archivo.",
-    "Pick a template for {name}" : "Selecciona una plantilla para {name}.",
-    "Create" : "Crear",
-    "Create a new file with the selected template" : "Crea un archivo nuevo con la plantilla seleccionada.",
-    "Creating file" : "Creando archivo.",
+    "Owner" : "Dueño",
+    "Remove from favorites" : "Eliminar de favoritos",
+    "Add to favorites" : "Agregar a favoritos",
+    "Tags" : "Etiquetas",
     "Blank" : "En blanco",
     "Unable to create new file from template" : "No se pudo crear un nuevo archivo a partir de la plantilla.",
+    "Pick a template for {name}" : "Selecciona una plantilla para {name}.",
+    "Create a new file with the selected template" : "Crea un archivo nuevo con la plantilla seleccionada.",
+    "Creating file" : "Creando archivo.",
+    "Leave this share" : "Salir de esta compartición.",
+    "Disconnect storage" : "Desconectar almacenamiento",
     "Delete permanently" : "Borrar permanentemente",
+    "Delete file" : "Eliminar archivo",
+    "Delete files" : "Eliminar archivos",
+    "Delete" : "Borrar",
+    "Cancel" : "Cancelar",
+    "Copy" : "Copiar",
+    "Move" : "Mover",
+    "Move or copy" : "Mover o copiar",
     "Open folder {displayName}" : "Abrir carpeta {displayName}.",
+    "Open file locally" : "Abrir archivo localmente",
+    "Failed to redirect to client" : "No se pudo redirigir al cliente.",
+    "Open locally" : "Abrir localmente",
+    "Rename" : "Renombrar",
     "Open details" : "Abrir detalles.",
-    "Create new templates folder" : "Crear nueva carpeta de plantillas.",
-    "Templates" : "Plantillas",
+    "View in folder" : "Ver en la carpeta",
+    "Today" : "Hoy",
+    "Documents" : "Documentos",
+    "Audio" : "Audio",
+    "Videos" : "Videos",
     "Unable to initialize the templates directory" : "No se pudo inicializar el directorio de plantillas.",
-    "List of favorites files and folders." : "Lista de archivos y carpetas favoritos.",
+    "Templates" : "Plantillas",
+    "Some files could not be moved" : "Algunos archivos no se pudieron mover",
+    "This operation is forbidden" : "Esta operación está prohibida",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verfica las bitácoras o contacta al administrador",
+    "Storage is temporarily not available" : "El almacenamiento no está disponible temporalmente ",
+    "_%n file_::_%n files_" : ["%n archivo","%n archivos","%n archivos"],
+    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas","%n carpetas"],
     "No favorites yet" : "Aún no hay favoritos",
     "Files and folders you mark as favorite will show up here" : "Los archivos y carpetas que marques como favoritos se mostrarán aquí. ",
     "All files" : "Todos los archivos",
+    "Recent" : "Reciente",
     "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
     "Select all" : "Seleccionar todo",
     "Upload too large" : "La carga es demasido grande",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que estás intentando cargar sobrepasan el tamaño máximo permitido para la carga de archivos en este servidor.",
+    "File could not be found" : "No fue posible encontrar el archivo",
+    "Download" : "Descargar",
+    "Show list view" : "Mostrar vista de lista",
+    "Show grid view" : "Mostrar vista de cuadrícula",
+    "Close" : "Cerrar",
+    "Could not create folder \"{dir}\"" : "No fue posible crear la carpeta \"{dir}\"",
+    "This will stop your current uploads." : "Esto detendrá tus cargas actuales.",
+    "Upload cancelled." : "Carga cancelada.",
+    "Processing files …" : "Procesando archivos...",
+    "…" : "...",
+    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No fue posible cargar {filename} ya que es una carpeta o tiene un tamaño de 0 bytes",
+    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No tienes suficiente espacio disponible, Estás cargando {size1} pero sólo cuentas con {size2} disponible",
+    "Target folder \"{dir}\" does not exist any more" : "La carpeta destino \"{dir}\" ya no existe",
+    "An unknown error has occurred" : "Ha ocurrido un error desconocido.",
+    "File could not be uploaded" : "No se pudo cargar el archivo.",
+    "Uploading …" : "Cargando...",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
+    "Uploading that item is not supported" : "No se admite la carga de ese elemento.",
+    "Error when assembling chunks, status code {status}" : "Se presentó un error al ensamblar los bloques, código de estatus {status}",
+    "Choose target folder" : "Selecciona la carpeta de destino.",
+    "Edit locally" : "Editar localmente.",
+    "Open" : "Abrir",
+    "Could not load info for file \"{file}\"" : "No fue posible cargar información para el archivo \"{file}\"",
+    "Details" : "Detalles",
+    "Please select tag(s) to add to the selection" : "Selecciona la(s) etiqueta(s) para agregar a la selección.",
+    "Apply tag(s) to selection" : "Aplicar etiqueta(s) a la selección.",
+    "Select directory \"{dirName}\"" : "Selecciona el directorio \"{dirName}\".",
+    "Select file \"{fileName}\"" : "Selecciona el archivo \"{fileName}\".",
+    "Unable to determine date" : "No fue posible determinar la fecha",
+    "Could not move \"{file}\", target exists" : "No fue posible mover \"{file}\", el destino ya existe",
+    "Could not move \"{file}\"" : "No fue posible mover \"{file}\"",
+    "copy" : "copia",
+    "Could not copy \"{file}\", target exists" : "No se pudo copiar \"{file}\", el destino ya existe",
+    "Could not copy \"{file}\"" : "No se pudo copiar \"{file}\"",
+    "Copied {origin} inside {destination}" : "{origin} fue copiado dentro de {destination}",
+    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} y otros {nbfiles} archivos fueron copiados dentro de {destination}",
+    "{newName} already exists" : "{newName} ya existe",
+    "Could not rename \"{fileName}\", it does not exist any more" : "No fue posible renombrar \"{fileName}\", ya no existe",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nombre \"{targetName}\" ya está en uso en la carpeta \"{dir}\". Por favor elege un nombre diferete. ",
+    "Could not rename \"{fileName}\"" : "No fue posible renombrar \"{fileName}\"",
+    "Could not create file \"{file}\"" : "No fue posible crear el archivo \"{file}\"",
+    "Could not create file \"{file}\" because it already exists" : "No fue posible crear el archivo\"{file}\" porque ya existe",
+    "Could not create folder \"{dir}\" because it already exists" : "No fue posible crear la carpeta \"{dir}\" porque ya existe",
+    "Could not fetch file details \"{file}\"" : "No se pudieron obtener los detalles del archivo \"{file}\".",
+    "Error deleting file \"{fileName}\"." : "Se presentó un error al borrar el archivo \"{fileName}\".",
+    "No search results in other folders for {tag}{filter}{endtag}" : "No se encontraron resultados en otras carpetas para  {tag}{filter}{endtag}",
+    "Enter more than two characters to search in other folders" : "Ingresa más de dos caracteres para buscar en otras carpetas.",
+    "{dirs} and {files}" : "{dirs} y {files}",
+    "_including %n hidden_::_including %n hidden_" : ["incluyendo %n oculto","incluyendo %n ocultos","incluyendo %n ocultos"],
+    "You do not have permission to upload or create files here" : "No tienes permiso para cargar o crear archivos aquí.",
+    "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Cargando %n archivos","Cargando %n archivos"],
+    "New" : "Nuevo",
+    "New file/folder menu" : "Menú de archivo/carpeta nuevo.",
+    "Select file range" : "Selecciona un rango de archivos.",
+    "{used}%" : "{used}%",
+    "{used} used" : "{used} usados",
+    "\"{name}\" is an invalid file name." : "\"{name}\" es un nombre de archivo inválido. ",
+    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
+    "\"/\" is not allowed inside a file name." : "No se permite el uso del caracter \"/\" en el nombre del archivo.",
+    "\"{name}\" is not an allowed filetype" : "\"{name}\" es un tipo de archivo no permitido",
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "El almacenamiento de {owner} está lleno, no se pueden actualizar ni sincronizar archivos.",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "La carpeta de grupo \"{mountPoint}\" está llena, no se pueden actualizar ni sincronizar archivos.",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "El almacenamiento externo \"{mountPoint}\" está lleno, no se pueden actualizar ni sincronizar archivos.",
+    "Your storage is full, files cannot be updated or synced anymore!" : "Tu almacenamiento está lleno, no se pueden actualizar ni sincronizar archivos.",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "El almacenamiento de {owner} está casi lleno ({usedSpacePercent}%).",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "La carpeta de grupo \"{mountPoint}\" está casi llena ({usedSpacePercent}%).",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "El almacenamiento externo \"{mountPoint}\" está casi lleno ({usedSpacePercent}%).",
+    "Your storage is almost full ({usedSpacePercent}%)." : "Tu almacenamiento está casi lleno ({usedSpacePercent}%).",
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["coincide con \"{filter}\".","coincide con \"{filter}\".","coincide con \"{filter}\"."],
+    "Path" : "Ruta",
+    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
+    "Favorited" : "Marcado como favorito",
+    "Upload file" : "Cargar archivo",
+    "Not favorited" : "No es un favorito",
+    "An error occurred while trying to update the tags" : "Se presentó un error al intentar actualizar la etiqueta",
+    "Storage informations" : "Información de almacenamiento.",
+    "Go to the previous folder" : "Ir a la carpeta anterior.",
+    "Open the files app settings" : "Abrir la configuración de la aplicación de archivos.",
+    "Unable to change the favourite state of the file" : "No se puede cambiar el estado de favorito del archivo.",
+    "Create new templates folder" : "Crear nueva carpeta de plantillas.",
+    "List of favorites files and folders." : "Lista de archivos y carpetas favoritos.",
     "Text file" : "Archivo de texto",
-    "New text file.txt" : "Nuevo ArchivoDeTexto.txt",
-    "You can only favorite a single file or folder at a time" : "Solo puedes marcar como favorito un archivo o carpeta a la vez.",
-    "Search users" : "Buscar usuarios.",
-    "You might not have have permissions to view it, ask the sender to share it" : "Puede que no tengas permisos para verlo. Pide al remitente que lo comparta contigo.",
-    "Cancel" : "Cancelar",
-    "Set up templates folder" : "Configurar carpeta de plantillas.",
-    "Toggle %1$s sublist" : "Alternar sublista de %1$s.",
-    "Toggle grid view" : "Alternar vista en cuadrícula.",
-    "Deleted files" : "Papelera",
-    "Shares" : "Elementos compartidos",
-    "Shared with others" : "Compartido con otros",
-    "Shared with you" : "Compartido con usted",
-    "Deleted shares" : "Comparticiones eliminadas",
-    "Pending shares" : "Comparticiones pendientes",
-    "This file has the tag {tag}" : "Este archivo tiene la etiqueta {tag}.",
-    "This file has the tags {firstTags} and {lastTag}" : "Este archivo tiene las etiquetas {firstTags} y {lastTag}.",
-    "Select the row for {displayName}" : "Seleccionar la fila para {displayName}.",
-    "Open folder {name}" : "Abrir carpeta {name}",
-    "Unselect all" : "Desmarcar todo.",
-    "ascending" : "ascendente",
-    "descending" : "descendente",
-    "Sort list by {column} ({direction})" : "Ordenar lista por {column} ({direction}).",
-    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Esta lista no se muestra completamente por motivos de rendimiento. Los archivos se mostrarán a medida que navegas por la lista.",
-    "Search for an account" : "Buscar una cuenta",
-    "Choose" : "Seleccionar",
-    "No files or folders have been deleted yet" : "No se han eliminado archivos o carpetas todavía."
+    "New text file.txt" : "Nuevo ArchivoDeTexto.txt"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
