@@ -46,6 +46,14 @@ OC.L10N.register(
     "Failed to authorize" : "Impossibile dare l'autorizzazione",
     "Invalid folder path" : "Percorso della cartella non valido",
     "Folder not found" : "Cartella non trovata",
+    "The file cannot be found" : "Il file non può essere trovato",
+    "The destination path does not exist: %1$s" : "Il percorso di destinazione non esiste: %1$s",
+    "You do not have permission to create a file at the specified location" : "Non hai l'autorizzazione per creare un file nella posizione specificata",
+    "The file could not be converted." : "Il file non può essere convertito.",
+    "Could not get relative path to converted file" : "Impossibile ottenere il percorso relativo al file convertito",
+    "Favorite files" : "File preferiti",
+    "No favorites" : "Nessun preferito",
+    "More favorites" : "Altri preferiti",
     "Upload (max. %s)" : "Carica (massimo %s)",
     "Accept" : "Accetta",
     "Reject" : "Rifiuta",
@@ -63,68 +71,69 @@ OC.L10N.register(
     "Transferred from %1$s on %2$s" : "Trasferito da %1$s su %2$s",
     "Files compatibility" : "Compatibilità di File",
     "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Consenti di limitare i nomi di file per assicurarsi che i file vengano sincronizzati con tutti i client. In modo predefinito, tutti i nomi di file validi su POSIX (es. Linux o macOS) sono consentiti.",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Dopo aver abilitato i nomi file compatibili con Windows, i file esistenti non potranno più essere modificati, ma potranno essere rinominati con nuovi nomi validi dal rispettivo proprietario.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "È anche possibile migrare i file automaticamente dopo aver abilitato questa impostazione; fare riferimento alla documentazione relativa al comando occ.",
     "Enforce Windows compatibility" : "Imponi la compatibilità con Windows",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Ciò bloccherà i nomi di file non validi sui sistemi Windows, come l'uso di nomi riservati o caratteri speciali. Tuttavia non verrà imposta la compatibilità con le maiuscole/minuscole.",
     "File Management" : "Gestione dei file",
-    "Current directory path" : "Percorso della cartella corrente",
     "Home" : "Home",
     "Target folder does not exist any more" : "La cartella di destinazione non esiste più",
     "Reload current directory" : "Ricarica la cartella corrente",
     "Go to the \"{dir}\" directory" : "Vai alla cartella \"{dir}\"",
-    "Drag and drop files here to upload" : "Trascina i file qui per caricarli",
+    "Current directory path" : "Percorso della cartella corrente",
     "Your have used your space quota and cannot upload files anymore" : "Hai esaurito la tua quota di spazio e non puoi più caricare file",
-    "You don’t have permission to upload or create files here" : "Qui non hai i permessi per caricare o creare file",
+    "You do not have permission to upload or create files here." : "Non hai l'autorizzazione per caricare o creare file qui.",
+    "Drag and drop files here to upload" : "Trascina i file qui per caricarli",
     "Favorite" : "Preferito",
-    "\"{displayName}\" action executed successfully" : "L'azione \"{displayName}\" è stata eseguita correttamente",
-    "\"{displayName}\" action failed" : "L'azione \"{displayName}\" non è riuscita",
+    "Back" : "Indietro",
     "Toggle selection for file \"{displayName}\"" : "Attiva/disattiva la selezione per il file \"{displayName}\"",
     "Toggle selection for folder \"{displayName}\"" : "Attiva/disattiva la selezione per la cartella \"{displayName}\"",
     "File is loading" : "Il file è in caricamento",
     "Folder is loading" : "La cartella è in caricamento",
-    "Rename file" : "Rinomina file",
     "Filename" : "Nome file",
     "Folder name" : "Nome della cartella",
     "This node is unavailable" : "Questa nodo non è disponibile",
     "Another entry with the same name already exists." : "Esiste già un'altra voce con lo stesso nome.",
     "Invalid filename." : "Nome di file non valido.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Rinominato \"{oldName}\" in \"{newName}\"",
+    "Rename file" : "Rinomina file",
+    "Folder" : "Cartella",
     "Pending" : "In corso",
+    "Unknown date" : "Data sconosciuta",
     "Clear filter" : "Pulisci il filtro",
     "Modified" : "Modificato",
     "Type" : "Tipo",
     "Active filters" : "Filtri attivi",
     "Remove filter" : "Rimuovi filtro",
     "Total rows summary" : "Riepilogo totale delle righe",
+    "Toggle selection for all files and folders" : "Attiva/disattiva la selezione per tutti i file e le cartelle",
     "Name" : "Nome",
     "Size" : "Dimensione",
-    "Toggle selection for all files and folders" : "Attiva/disattiva la selezione per tutti i file e le cartelle",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" non riuscito su alcuni elementi",
+    "\"{displayName}\" batch action executed successfully" : "L'azione batch \"{displayName}\" è stata eseguita correttamente",
+    "\"{displayName}\" action failed" : "L'azione \"{displayName}\" non è riuscita",
     "Actions" : "Azioni",
     "(selected)" : "(selezionato)",
-    "\"{displayName}\" failed on some elements " : "\"{displayName}\" non è riuscita su alcuni elementi",
-    "\"{displayName}\" batch action executed successfully" : "L'azione batch \"{displayName}\" è stata eseguita correttamente",
-    "{count} selected" : "{count} selezionati",
     "List of files and folders." : "Lista di file e cartelle.",
+    "You have used your space quota and cannot upload files anymore." : "Hai esaurito la tua quota di spazio e non puoi più caricare file.",
     "Column headers with buttons are sortable." : "Le intestazioni di colonna con pulsanti sono ordinabili.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Questa lista non è stata mostrata completamente per ragioni di prestazioni. I file verranno mostrati durante la navigazione della lista.",
     "File not found" : "File non trovato",
-    "Storage information" : "Informazioni di archiviazione",
-    "Storage quota" : "Limite di archiviazione",
+    "{count} selected" : "{count} selezionati",
     "{usedQuotaByte} used" : "{usedQuotaByte} usato",
     "{used} of {quota} used" : "{used} di {quota} utilizzati",
     "{relative}% used" : "{relative}% usato",
     "Could not refresh storage stats" : "Impossibile aggiornare le statistiche di archiviazione",
     "Your storage is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione è pieno, i file non possono essere più aggiornati o sincronizzati!",
-    "Create" : "Crea",
+    "Storage information" : "Informazioni di archiviazione",
+    "Storage quota" : "Limite di archiviazione",
     "New folder" : "Nuova cartella",
     "Create new folder" : "Crea una nuova cartella",
     "This name is already in use." : "Questo nome è già utilizzato.",
+    "Create" : "Crea",
     "Fill template fields" : "Compila i campi del modello",
-    "Submitting fields…" : "Invio dei campi…",
+    "Submitting fields …" : "Invio dei campi …",
     "Submit" : "Invia",
-    "Transfer ownership of a file or folder" : " Trasferisci la proprietà di un file o di una cartella",
-    "Choose file or folder to transfer" : "Scegli file o cartella da trasferire",
-    "Change" : "Modifica",
-    "New owner" : "Nuovo proprietario",
     "Choose a file or folder to transfer" : "Scegli file o cartella da trasferire",
     "Transfer" : "Trasferisci",
     "Transfer {path} to {userid}" : "Trasferisci {path} a {userid}",
@@ -132,32 +141,48 @@ OC.L10N.register(
     "Unknown error" : "Errore sconosciuto",
     "Ownership transfer request sent" : "Richiesta di trasferimento della proprietà inviata",
     "Cannot transfer ownership of a file or folder you do not own" : "Impossibile trasferire la proprietà di un file o di una cartella di cui non sei proprietario",
+    "Transfer ownership of a file or folder" : " Trasferisci la proprietà di un file o di una cartella",
+    "Choose file or folder to transfer" : "Scegli file o cartella da trasferire",
+    "Change" : "Modifica",
+    "New owner" : "Nuovo proprietario",
+    "Keep {old}" : "Mantieni {old}",
+    "Keep without extension" : "Mantenere senza estensione",
+    "Use {new}" : "Usa {new}",
+    "Remove extension" : "Rimuovi estensione",
+    "Change file extension" : "Cambia estensione file",
+    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Modificando l'estensione del file da \"{old}\" a\"{new}\" potrebbe rendere il file illeggibile.",
+    "Removing the file extension \"{old}\" may render the file unreadable." : "Rimuovendo dell'estensione del file \"{old}\" potrebbe rendere il file illeggibile.",
+    "Adding the file extension \"{new}\" may render the file unreadable." : "Aggiungere l'estensione del file \"{new}\" potrebbe rendere il file illeggibile.",
+    "Do not show this dialog again." : "Non visualizzare più questa finestra di dialogo.",
     "Select file or folder to link to" : "Seleziona un file o una cartella da collegare",
     "Choose {file}" : "Scegli {file}",
-    "New" : "Nuovo",
-    "Loading current folder" : "Sto caricando la cartella corrente",
-    "Retry" : "Riprova",
-    "No files in here" : "Qui non c'è alcun file",
-    "Upload some content or sync with your devices!" : "Carica dei contenuti o sincronizza con i tuoi dispositivi!",
-    "Go back" : "Indietro",
     "Share" : "Condividi",
     "Shared by link" : "Condivisi tramite collegamento",
     "Shared" : "Condiviso",
     "Switch to list view" : "Passa alla vista elenco",
     "Switch to grid view" : "Passa alla vista griglia",
+    "The file could not be found" : "Il file non è stato trovato",
     "Upload was cancelled by user" : "Caricamento annullato dall'utente",
     "Not enough free space" : "Spazio libero insufficiente",
     "Operation is blocked by access control" : "L'operazione è bloccata dal controllo di accesso",
     "Error during upload: {message}" : "Errore durante il caricamento: {message}",
     "Error during upload, status code {status}" : "Errore durante il caricamento, codice di stato {status}",
     "Unknown error during upload" : "Errore sconosciuto durante il caricamento",
-    "Filter filenames…" : "Filtra nomi di file…",
+    "\"{displayName}\" action executed successfully" : "L'azione \"{displayName}\" è stata eseguita correttamente",
+    "Loading current folder" : "Sto caricando la cartella corrente",
+    "Retry" : "Riprova",
+    "No files in here" : "Qui non c'è alcun file",
+    "Upload some content or sync with your devices!" : "Carica dei contenuti o sincronizza con i tuoi dispositivi!",
+    "Go back" : "Indietro",
+    "Filter file names …" : "Filtra i nomi dei file …",
     "Views" : "Viste",
     "Files settings" : "Impostazioni File",
-    "File cannot be accessed" : "Il file non possono essere acceduti",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Impossibile trovare il file oppure non disponi dei permessi per visualizzarlo. Chiedi al mittente di condividerlo.",
     "Your files" : "I tuoi files",
     "Open in files" : "Apri in file",
+    "File cannot be accessed" : "Il file non possono essere acceduti",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Impossibile trovare il file oppure non disponi dei permessi per visualizzarlo. Chiedi al mittente di condividerlo.",
+    "Clipboard is not available" : "Appunti non disponibili",
+    "WebDAV URL copied to clipboard" : "L'URL WebDAV è stato copiato negli appunti",
     "Sort favorites first" : "Ordina prima i preferiti",
     "Sort folders before files" : "Ordina cartelle prima dei files",
     "Show hidden files" : "Mostra i file nascosti",
@@ -170,28 +195,64 @@ OC.L10N.register(
     "Copy to clipboard" : "Copia negli appunti",
     "Use this address to access your Files via WebDAV" : "Usa questo indirizzo per accedere ai tuoi file con WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Se hai abilitato il 2FA, devi creare ed usare una nuova password per l'applicazione facendo clic qui.",
-    "Clipboard is not available" : "Appunti non disponibili",
-    "WebDAV URL copied to clipboard" : "L'URL WebDAV è stato copiato negli appunti",
+    "Warnings" : "Avvertenze",
+    "Prevent warning dialogs from open or reenable them." : "Impedire l'apertura delle finestre di dialogo di avviso o riattivarle.",
+    "Show a warning dialog when changing a file extension." : "Mostra una finestra di dialogo di avviso quando si modifica l'estensione di un file.",
+    "Keyboard shortcuts" : "Scorciatoie da tastiera",
+    "Speed up your Files experience with these quick shortcuts." : "Velocizza la tua esperienza con i File con queste rapide scorciatoie.",
+    "Open the actions menu for a file" : "Aprire il menu delle azioni per un file",
+    "Rename a file" : "Rinominare un file",
+    "Delete a file" : "Eliminare un file",
+    "Favorite or remove a file from favorites" : "Aggiungere ai Preferiti o rimuovere un file dai preferiti",
+    "Manage tags for a file" : "Gestire i tag per un file",
+    "Selection" : "Selezione",
+    "Select all files" : "Seleziona tutti i file",
+    "Deselect all files" : "Deseleziona tutti i file",
+    "Select or deselect a file" : "Seleziona o deseleziona un file",
+    "Select a range of files" : "Seleziona un intervallo di file",
+    "Navigation" : "Navigazione",
+    "Navigate to the parent folder" : "Passare alla cartella padre",
+    "Navigate to the file above" : "Vai al file sopra",
+    "Navigate to the file below" : "Vai al file qui sotto",
+    "Navigate to the file on the left (in grid mode)" : "Navigare nel file a sinistra (in modalità griglia)",
+    "Navigate to the file on the right (in grid mode)" : "Navigare nel file a destra (in modalità griglia)",
+    "View" : "Visualizza",
+    "Toggle the grid view" : "Attiva la vista a griglia",
+    "Open the sidebar for a file" : "Aprire la barra laterale per un file",
+    "Show those shortcuts" : "Mostra quelle scorciatoie",
+    "You" : "Tu",
+    "Shared multiple times with different people" : "Condiviso più volte con diverse persone",
+    "Error while loading the file data" : "Errore durante il caricamento del file di dati",
     "Owner" : "Proprietario",
     "Remove from favorites" : "Rimuovi dai preferiti",
     "Add to favorites" : "Aggiungi ai preferiti",
     "Tags" : "Etichette",
-    "You" : "Tu",
-    "Shared multiple times with different people" : "Condiviso più volte con diverse persone",
-    "Unable to change the favourite state of the file" : "Impossibile cambiare lo stato di preferito del file",
-    "Error while loading the file data" : "Errore durante il caricamento del file di dati",
+    "Blank" : "Vuoto",
+    "Unable to create new file from template" : "Impossibile creare un nuovo file dal modello",
     "Pick a template for {name}" : "Scegli un modello per {name}",
     "Create a new file with the selected template" : "Crea un nuovo file con il modello selezionato",
     "Creating file" : "Creazione del file",
-    "Blank" : "Vuoto",
-    "Unable to create new file from template" : "Impossibile creare un nuovo file dal modello",
+    "Save as {displayName}" : "Savlva come {displayName}",
+    "Save as …" : "Salva come …",
+    "Converting files …" : "Conversione dei file …",
+    "Failed to convert files: {message}" : "Impossibile convertire i file: {message}",
+    "All files failed to be converted" : "Non è stato possibile convertire tutti i file",
+    "One file could not be converted: {message}" : "Un file non può essere convertito: {message}",
+    "_One file could not be converted_::_%n files could not be converted_" : ["Un file non è stato convertito","%nfile non possono essere convertiti","%n file non possono essere convertiti"],
+    "_One file successfully converted_::_%n files successfully converted_" : ["Un file convertito correttamente","%nfile convertiti con successo","%n file convertiti con successo"],
+    "Files successfully converted" : "File convertiti con successo",
+    "Failed to convert files" : "Impossibile convertire i file",
+    "Converting file …" : "Conversione del file …",
+    "File successfully converted" : "File convertito con successo",
+    "Failed to convert file: {message}" : "Impossibile convertire il file: {message}",
+    "Failed to convert file" : "Impossibile convertire il file",
     "Deletion cancelled" : "Eliminazione annullata",
-    "Delete permanently" : "Elimina permanentemente",
-    "Delete and unshare" : "Elimina e annulla la condivisione",
     "Leave this share" : "Abbandona questa condivisione",
     "Leave these shares" : "Abbandona queste condivisioni",
     "Disconnect storage" : "Disconnetti archiviazione",
     "Disconnect storages" : "Disconnetti il supporto di archiviazione",
+    "Delete permanently" : "Elimina permanentemente",
+    "Delete and unshare" : "Elimina e annulla la condivisione",
     "Delete file" : "Elimina file",
     "Delete files" : "Elimina i file",
     "Delete folder" : "Elimina cartella",
@@ -201,12 +262,6 @@ OC.L10N.register(
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Stai per eliminare {count} elemento","Stai per eliminare {count} elementi","Stai per eliminare {count} elementi"],
     "Confirm deletion" : "Conferma l'eliminazione",
     "Cancel" : "Annulla",
-    "Edit file locally" : "Modifica il file localmente",
-    "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system." : "I file dovrebbe ora aprirsi in locale. Se non succede, assicurati che il client desktop sia installato nel tuo sistema.",
-    "Retry local edit" : "Riprova modifica in locale",
-    "Edit online" : "Modifica online",
-    "Failed to redirect to client" : "Reindirizzamento al client non riuscito",
-    "Edit locally" : "Modifica localmente",
     "Moving \"{source}\" to \"{destination}\" …" : "Sposta \"{source}\" in \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Copia \"{source}\" in \"{destination}\" …",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Non puoi spostare un file/cartella in se stesso o in una sottocartella di se stesso",
@@ -227,6 +282,12 @@ OC.L10N.register(
     "Cancelled move or copy operation" : "Operazione di spostamento o copia annullata",
     "Open folder {displayName}" : "Apri la cartella {displayName}",
     "Open in Files" : "Apri in File",
+    "Open file locally" : "Apri file localmente",
+    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Il file dovrebbe ora aprirsi sul tuo dispositivo. In caso contrario, controlla di aver installato l'app desktop.",
+    "Retry and close" : "Riprova e chiudi",
+    "Open online" : "Apri online",
+    "Failed to redirect to client" : "Reindirizzamento al client non riuscito",
+    "Open locally" : "Aprire localmente",
     "Rename" : "Rinomina",
     "Open details" : "Apri i dettagli",
     "View in folder" : "Visualizza nella cartella",
@@ -267,11 +328,10 @@ OC.L10N.register(
     "This operation is forbidden" : "Questa operazione è vietata",
     "This directory is unavailable, please check the logs or contact the administrator" : "Questa cartella non è disponibile, controlla i log o contatta l'amministratore",
     "Storage is temporarily not available" : "L'archiviazione è temporaneamente non disponibile",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} cartella","{folderCount} cartelle","{folderCount} cartelle"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} file","{fileCount} file","{fileCount} file"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 file e {folderCount} cartella","1 file e {folderCount} cartelle","1 file e {folderCount} cartelle"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} file e 1 cartella","{fileCount} file e 1 cartella","{fileCount} file e 1 cartella"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} file e {folderCount} cartelle",
+    "Unexpected error: {error}" : "Errore imprevisto: {error}",
+    "_%n file_::_%n files_" : ["%n file","%n file","%n file"],
+    "_%n folder_::_%n folders_" : ["%n cartella","%n cartelle","%n cartelle"],
+    "_%n hidden_::_%n hidden_" : ["%n nascosto","%n nascosti","%n nascosti"],
     "Filename must not be empty." : "Il nome del file non può essere vuoto.",
     "\"{char}\" is not allowed inside a filename." : "\"{char}\" non è consentito in un nome di file.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" è un nome riservato e non consentito per i nomi di file.",
@@ -283,7 +343,7 @@ OC.L10N.register(
     "All files" : "Tutti i file",
     "List of your files and folders." : "Lista dei tuoi file e cartelle.",
     "All folders" : "Tutte le cartelle",
-    "Personal Files" : "File personali",
+    "Personal files" : "File personali",
     "List of your files and folders that are not shared." : "Elenco dei file e delle cartelle che non sono condivisi.",
     "No personal files found" : "Nessun file personale trovato",
     "Files that are not shared will show up here." : "I file che non vengono condivisi verranno visualizzati qui.",
@@ -291,7 +351,6 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Lista di file e cartelle modificati di recente.",
     "No recently modified files" : "Nessun file modificato di recente",
     "Files and folders you recently modified will show up here." : "I file e le cartelle che hai modificato di recente saranno mostrati qui.",
-    "You do not have permission to upload or create files here" : "Non disponi dei permessi per caricare o creare file qui",
     "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
     "Select all" : "Seleziona tutto",
     "Upload too large" : "Caricamento troppo grande",
@@ -319,6 +378,7 @@ OC.L10N.register(
     "Error when assembling chunks, status code {status}" : "Errore durante l'assemblaggio dei blocchi, codice di stato {status}",
     "Choose target folder" : "Scegli la cartella di destinazione",
     "Set reminder" : "Imposta promemoria",
+    "Edit locally" : "Modifica localmente",
     "Open" : "Apri",
     "Could not load info for file \"{file}\"" : "Impossibile caricare le informazioni per il file \"{file}\"",
     "Details" : "Dettagli",
@@ -345,11 +405,11 @@ OC.L10N.register(
     "Error deleting file \"{fileName}\"." : "Errore durante l'eliminazione del file \"{fileName}\".",
     "No search results in other folders for {tag}{filter}{endtag}" : "Nessun risultato di ricerca nelle altre cartelle per {tag}{filter}{endtag}",
     "Enter more than two characters to search in other folders" : "Digita più di due caratteri per cercare in altre cartelle",
-    "_%n folder_::_%n folders_" : ["%n cartella","%n cartelle","%n cartelle"],
-    "_%n file_::_%n files_" : ["%n file","%n file","%n file"],
     "{dirs} and {files}" : "{dirs} e {files}",
     "_including %n hidden_::_including %n hidden_" : ["incluso %n nascosto","inclusi %n nascosti","inclusi %n nascosti"],
+    "You do not have permission to upload or create files here" : "Non disponi dei permessi per caricare o creare file qui",
     "_Uploading %n file_::_Uploading %n files_" : ["Caricamento di %n file in corso","Caricamento di %n file in corso","Caricamento di %n file in corso"],
+    "New" : "Nuovo",
     "New file/folder menu" : "Nuovo menu file/cartella",
     "Select file range" : "Seleziona intervallo di file",
     "{used}%" : "{used}%",
@@ -367,40 +427,38 @@ OC.L10N.register(
     "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "L'archiviazione esterna \"{mountPoint}\" è quasi piena ({usedSpacePercent}%).",
     "Your storage is almost full ({usedSpacePercent}%)." : "Lo spazio di archiviazione è quasi pieno ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["verifica \"{filter}\"","verificano \"{filter}\"","verificano \"{filter}\""],
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Il collegamento diretto è stato copiato (funziona solo per gli utenti che hanno accesso a questo file o cartella)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Il collegamento diretto è stato copiato (funziona solo per gli utenti che hanno accesso a questo file o cartella)",
     "Path" : "Percorso",
     "_%n byte_::_%n bytes_" : ["%n byte","%n byte","%n byte"],
     "Favorited" : "Preferiti",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Copia collegamento diretto (funziona solo per utenti che hanno accesso a questo file/cartella)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Copia collegamento diretto (funziona solo per utenti che hanno accesso a questo file/cartella)",
     "Upload file" : "Carica file",
     "Not favorited" : "Non preferito",
     "An error occurred while trying to update the tags" : "Si è verificato un errore durante il tentativo di aggiornare le etichette",
-    "\"remote user\"" : "\"utente remoto\"",
-    "{newName} already exists." : "{newName} esiste già.",
-    "\"{segment}\" is not allowed inside a filename." : "\"{segment}\" non è consentito in un nome di file.",
-    "\"{segment}\" is a forbidden file or folder name." : "\"{segment}\" è un nome vietato per file o cartelle.",
-    "\"{segment}\" is not an allowed filetype." : "\"{segment}\" non è un tipo di file consentito.",
-    "Filenames must not end with \"{segment}\"." : "I nomi di file non possono terminare con \"{segment}\".",
-    "Name cannot be empty" : "Il nome non può essere vuoto",
-    "Another entry with the same name already exists" : "Esiste già un'altra voce con lo stesso nome",
-    "Could not rename \"{oldName}\", it does not exist any more" : "Impossibile rinominare \"{oldName}\", non esiste più",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Il nome \"{newName}\" è attualmente in uso nella cartella \"{dir}\". Scegli un nome diverso.",
-    "Could not rename \"{oldName}\"" : "Impossibile rinominare \"{oldName}\"",
+    "You don't have permission to upload or create files here." : "Non hai l'autorizzazione per caricare o creare file qui.",
     "Storage informations" : "Informazioni di archiviazione",
     "Choose file" : "Scegli file",
     "Go to the previous folder" : "Vai alla cartella precedente",
     "Open the files app settings" : "Apri le impostazioni dell'applicazione File",
-    "You might not have have permissions to view it, ask the sender to share it" : "Potresti non avere i permessi per visualizzarlo, chiedi al mittente di condividerlo",
-    "The files is locked" : "Il file è bloccato",
+    "Unable to change the favourite state of the file" : "Impossibile cambiare lo stato di preferito del file",
+    "Edit file locally" : "Modifica il file localmente",
+    "Edit online" : "Modifica online",
     "Create new templates folder" : "Crea una nuova cartella dei modelli",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} cartella","{folderCount} cartelle","{folderCount} cartelle"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} file","{fileCount} file","{fileCount} file"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 file e {folderCount} cartella","1 file e {folderCount} cartelle","1 file e {folderCount} cartelle"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} file e 1 cartella","{fileCount} file e 1 cartella","{fileCount} file e 1 cartella"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} file e {folderCount} cartelle",
     "List of favorites files and folders." : "Lista di file e cartelle preferiti.",
-    "Toggle %1$s sublist" : "Passa alla sottolista %1$s",
+    "Personal Files" : "File personali",
     "Text file" : "File di testo",
     "New text file.txt" : "Nuovo file di testo.txt",
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Il collegamento diretto è stato copiato (funziona solo per gli utenti che hanno accesso a questo file o cartella)",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Copia collegamento diretto (funziona solo per utenti che hanno accesso a questo file/cartella)",
     "Favored" : "Preferito",
     "Favor" : "Preferiti",
-    "Not favored" : "Non preferito"
+    "Not favored" : "Non preferito",
+    "Submitting fields…" : "Invio dei campi…",
+    "Filter filenames…" : "Filtra nomi di file…",
+    "{count} files could not be converted" : "{count} file non possono essere convertiti",
+    "{count} files successfully converted" : "{count} file convertiti con successo"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
