@@ -1,20 +1,6 @@
 OC.L10N.register(
     "files_sharing",
     {
-    "Waiting…" : "正在等待……",
-    "error" : "錯誤",
-    "finished" : "已結束",
-    "This will stop your current uploads." : "這會終止目前任何的上傳。",
-    "Move or copy" : "移動或複製",
-    "Download" : "下載",
-    "Delete" : "移除",
-    "You can upload into this folder" : "你可以上傳內容到此資料夾",
-    "Terms of service" : "服務條款",
-    "Show list view" : "顯示清單視圖",
-    "Show grid view" : "顯示網格視圖",
-    "No compatible server found at {remote}" : "沒有在 {remote} 找到相容的伺服器",
-    "Invalid server URL" : "無效的伺服器 URL",
-    "Failed to add the public link to your Nextcloud" : "無法將公開連結加入您的 Nextcloud",
     "File shares" : "檔案分享",
     "Downloaded via public link" : "透過公用連結下載",
     "Downloaded by {email}" : "{email} 已下載",
@@ -69,8 +55,9 @@ OC.L10N.register(
     "Share for file {file} with {user} expired" : "與 {user} 分享的檔案 {file} 已過期",
     "Share for file {file} expired" : "檔案 {file} 的分享已過期",
     "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "email或公開連結分享的檔案與資料夾已被 <strong>下載</strong>",
+    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "檔案已<strong>上傳</strong>到透過郵件或公共連結的共享資料夾",
     "A file or folder was shared from <strong>another server</strong>" : "檔案或目錄已被 <strong>其他伺服器</strong> 分享",
-    "Files" : "檔案",
+    "Sharing" : "分享",
     "A file or folder has been <strong>shared</strong>" : "檔案或目錄已被 <strong>分享</strong>",
     "Shared link" : "已分享的連結",
     "Wrong share ID, share does not exist" : "錯誤的分享 ID ，分享不存在",
@@ -78,34 +65,46 @@ OC.L10N.register(
     "Please specify a file or folder path" : "請指定檔案或資料夾路徑",
     "Wrong path, file/folder does not exist" : "錯誤的路徑，該檔案或資料夾不存在",
     "Could not create share" : "無法建立分享",
-    "Invalid permissions" : "無效的權限",
-    "Please specify a valid user" : "請選擇一個有效的用戶",
+    "Please specify a valid account to share with" : "請指定要分享的有效帳戶",
     "Group sharing is disabled by the administrator" : "群組分享已被管理員停用",
     "Please specify a valid group" : "請指定一個有效的群組",
     "Public link sharing is disabled by the administrator" : "公開連結分享已被管理員停用",
-    "Public upload disabled by the administrator" : "公開上傳已被管理員停用",
-    "Public upload is only possible for publicly shared folders" : "只有公開分享的資料夾可以接受公開上傳",
+    "Please specify a valid email address" : "請指定一個有效的電郵地址",
     "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "因為未啟用 Nextcloud Talk，因此透過 Nextcloud Talk 傳送密碼分享 %s 失敗",
     "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "分享 %1$s 失敗，因為後端不允許來自 %2$s 類型的分享",
-    "Please specify a valid federated user ID" : "請指定一個有效的聯合用戶 ID",
-    "Invalid date, date format must be YYYY-MM-DD" : "無效的日期，需為 YYYY-MM-DD 格式",
+    "Please specify a valid federated account ID" : "請指定有效的聯盟帳戶 ID",
     "Please specify a valid federated group ID" : "請指定一個有效的聯合群組 ID",
-    "You cannot share to a Circle if the app is not enabled" : "當應用未被啟用，你無法分享到circle。",
-    "Please specify a valid circle" : "請指定一個有效的circle",
+    "You cannot share to a Team if the app is not enabled" : "當應用未被啟用，你無法分享到團隊。",
+    "Please specify a valid team" : "請選擇一個有效的團隊",
     "Sharing %s failed because the back end does not support room shares" : "分享 %s 失敗，因為後端不支援聊天室分享",
     "Sharing %s failed because the back end does not support ScienceMesh shares" : "分享 %s 失敗，因為後端不支援 ScienceMesh 分享",
     "Unknown share type" : "分享類型不詳",
     "Not a directory" : "這不是一個資料夾",
     "Could not lock node" : "無法鎖定節點",
-    "Could not lock path" : "無法鎖定路徑",
-    "Wrong or no update parameter given" : "更新參數不正確或未提供",
+    "Public upload is only possible for publicly shared folders" : "只有公開分享的資料夾可以接受公開上傳",
     "Share must at least have READ or CREATE permissions" : "分享必須至少具有 READ 或 CREATE 權限",
     "Share must have READ permission if UPDATE or DELETE permission is set" : "如果設置了 UPDATE 或 DELETE 權限，則分享必須具有 READ 權限",
+    "Public upload disabled by the administrator" : "公開上傳已被管理員停用",
+    "Could not lock path" : "無法鎖定路徑",
+    "no sharing rights on this item" : "此項目無共享權限",
+    "You are not allowed to edit incoming shares" : "您無權編輯接收的共享項目",
+    "Wrong or no update parameter given" : "更新參數不正確或未提供",
     "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "“通過 Nextcloud Talk 發送密碼”共享檔案或資料夾失敗，因為 Nextcloud Talk 未啟用。",
+    "Custom share link tokens have been disabled by the administrator" : "自訂分享連結權杖已被管理員停用",
+    "Tokens must contain at least 1 character and may only contain letters, numbers, or a hyphen" : "權杖必須至少包含 1 個字元，且只能包含字母、數字或連字符。",
+    "Invalid date. Format must be YYYY-MM-DD" : "無效的日期。需為 YYYY-MM-DD 格式",
+    "No sharing rights on this item" : "此項目無共享權限",
+    "Invalid share attributes provided: \"%s\"" : "提供的共享屬性無效：\"%s\"",
+    "You are not allowed to send mail notifications" : "您無權發送郵件通知",
+    "No mail notification configured for this share type" : "此共享類型未配置郵件通知。",
+    "Wrong password" : "密碼錯誤",
+    "Error while sending mail notification" : "發送郵件通知時發生錯誤",
+    "Failed to generate a unique token" : "產生獨一無二的權杖失敗",
+    "This share does not exist or is no longer available" : "此分享不存在或是不再提供",
     "shared by %s" : "分享自 %s",
-    "Download all files" : "下載所有檔案",
-    "Direct link" : "直接連結",
+    "Download" : "下載",
     "Add to your %s" : "新增至您的 %s",
+    "Direct link" : "直接連結",
     "Share API is disabled" : "分享 API 已停用",
     "File sharing" : "檔案分享",
     "Share will expire tomorrow" : "分享將於明日到期",
@@ -113,71 +112,130 @@ OC.L10N.register(
     "You received {share} as a share by {user}" : "您收到 {user} 的分享 {share}",
     "You received {share} to group {group} as a share by {user}" : "您收到了 {user} 分享的 {share} 到 {group} 群組",
     "Accept" : "接受",
-    "Reject" : "拒絕",
-    "This application enables users to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable users can then share files and folders with other users and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other users outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "該應用程序使用戶可以在Nextcloud中共享檔案。如果啟用，管理員可以選擇可以共享文件的群組。然後，適用的用戶可以與Nextcloud中的其他用戶和群組共享檔案和資料夾。此外，如果管理員啟用了共享連結功能，則可以使用外部連結與Nextcloud之外的其他用戶分享檔案。管理員還可以實施密碼，有效期，並允許通過分享檔案進行伺服器到伺服器的分享以及從流動裝置進行分享。\n關閉此功能將刪除伺服器上所有分享收件人以及同步客戶端和流動應用程序上的分享了檔案和資料夾。Nextcloud文檔中提供了更多信息。",
-    "Sharing" : "分享",
-    "Accept user and group shares by default" : "默認接受用戶和群組共享",
+    "Decline" : "婉拒",
+    "Remember to upload the files to %s" : "記得將檔案上傳至 %s",
+    "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "我們謹提醒您，您尚未將任何檔案上傳到共用資料夾。",
+    "Open \"%s\"" : "開啟「%s」",
+    "This application enables people to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable people can then share files and folders with other accounts and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other people outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "該應用程序使用戶可以在Nextcloud中共享檔案。如果啟用，管理員可以選擇可以共享檔案的群組。然後，適用的用戶可以與Nextcloud中的其他帳戶和群組共享檔案和資料夾。此外，如果管理員啟用了共享連結功能，則可以使用外部連結與Nextcloud之外的其他用戶分享檔案。管理員還可以實施密碼，有效期，並允許通過分享檔案進行伺服器到伺服器的分享以及從流動裝置進行分享。\n關閉此功能將刪除伺服器上所有分享收件人以及同步客戶端和流動應用程序上的分享了檔案和資料夾。Nextcloud文檔中提供了更多信息。",
+    "People" : "人物",
+    "Filter accounts" : "過濾帳戶",
+    "The request will expire on {date} at midnight and will be password protected." : "請求將於 {date} 凌晨過期，並將受到密碼保護。",
+    "The request will expire on {date} at midnight." : "請求將於 {date} 凌晨過期。",
+    "The request will be password protected." : "請求將受到密碼保護。",
+    "When should the request expire?" : "請求應在何時過期？",
+    "Set a submission expiration date" : "設置提交屆滿日期",
+    "Expiration date" : "到期日",
+    "Select a date" : "選擇日期",
+    "Your administrator has enforced a {count} days expiration policy." : "您的管理員已強制執行 {count} 天過期政策。",
+    "What password should be used for the request?" : "請求應使用什麼密碼？",
+    "Set a password" : "設定密碼",
+    "Password" : "密碼",
+    "Enter a valid password" : "輸入有效的密碼",
+    "Generate a new password" : "生成新密碼",
+    "Your administrator has enforced a password protection." : "您的管理員已強制設置密碼保護。",
+    "Automatically copying failed, please copy the share link manually" : "自動複製失敗，請手動複製共享連結。",
+    "Link copied to clipboard" : "已複製連結至剪貼板",
+    "Email already added" : "已加入電郵地址",
+    "Invalid email address" : "電郵地址無效",
+    "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["以下電子郵件地址無效：{emails}"],
+    "_{count} email address already added_::_{count} email addresses already added_" : ["已添加 {count} 個電郵地址"],
+    "_{count} email address added_::_{count} email addresses added_" : ["添加了{count}個電郵地址"],
+    "You can now share the link below to allow people to upload files to your directory." : "您現在可以分享下面的連結，以允許其他人將檔案上傳到您的目錄中。",
+    "Share link" : "分享連結",
+    "Copy to clipboard" : "複製到剪貼板",
+    "Send link via email" : "透過電郵寄送連結",
+    "Enter an email address or paste a list" : "請輸入電郵地址或粘貼一個清單",
+    "Remove email" : "移除電郵地址",
+    "Select a destination" : "選擇目的地",
+    "Select" : "選擇",
+    "What are you requesting?" : "您正在請求什麼？",
+    "Request subject" : "請求主題",
+    "Birthday party photos, History assignment…" : "生日派對照片、歷史作業 …",
+    "Where should these files go?" : "這些檔案應該放在哪裡？",
+    "Upload destination" : "上傳目標地",
+    "Revert to default" : "恢復默認值",
+    "The uploaded files are visible only to you unless you choose to share them." : "上傳的檔案僅對您可見，除非您選擇分享它們。",
+    "Add a note" : "添加筆記",
+    "Note for recipient" : "給收件人的備註",
+    "Add a note to help people understand what you are requesting." : "添加備註以幫助他人了解您的請求。",
+    "You can add links, date or any other information that will help the recipient understand what you are requesting." : "您可以新增連結、日期或任何其他訊息，以幫助收件人了解您的請求。",
+    "Close" : "關閉",
+    "_Send email and close_::_Send {count} emails and close_" : ["發送 {count} 封電子郵件並關閉"],
+    "Please select a folder, you cannot share the root directory." : "請選擇一個資料夾，您不能共享根目錄。",
+    "File request created" : "創建了檔案請求",
+    "_File request created and email sent_::_File request created and {count} emails sent_" : ["檔案請求已創建，{count}封電子郵件已發送"],
+    "Error creating the share: {errorMessage}" : "創建分享出錯：{errorMessage}",
+    "Error creating the share" : "創建分享出錯",
+    "Error sending emails: {errorMessage}" : "發送電子郵件時出錯：{errorMessage}",
+    "Error sending emails" : "發送電子郵件時出錯",
+    "Create a file request" : "創建檔案請求",
+    "Collect files from others even if they do not have an account." : "即使對方沒有帳戶，也可以收集檔案。",
+    "To ensure you can receive files, verify you have enough storage available." : "為了確保您能接收檔案，請確認您有足夠的可用儲存空間。",
+    "File request" : "檔案請求",
+    "Previous step" : "上一步",
+    "Cancel" : "取消",
+    "Cancel the file request creation" : "取消檔案請求創建",
+    "Close without sending emails" : "關閉而不發送電子郵件",
+    "Continue" : "繼續",
     "Error while toggling options" : "切換選項時出錯",
-    "Set default folder for accepted shares" : "為已接受的分享選擇一個默認資料夾",
-    "Reset" : "重設",
-    "Reset folder to system default" : "將資料夾重置為系統默認值",
+    "Accept shares from other accounts and groups by default" : "預設接受其他帳戶與群組的分享",
     "Choose a default folder for accepted shares" : "為已接受的分享選擇一個默認資料夾",
     "Invalid path selected" : "所選的路徑無效",
     "Unknown error" : "錯誤不詳",
-    "Allow editing" : "允許編輯",
-    "Read only" : "唯讀",
-    "Allow upload and editing" : "允許上傳及編輯",
-    "File drop (upload only)" : "拖曳檔案（僅供上傳）",
-    "Custom permissions" : "自訂權限",
-    "Read" : "讀取",
-    "Upload" : "上傳",
-    "Edit" : "編輯",
-    "Bundled permissions" : "權限包",
-    "Open Sharing Details" : "打開分享細節",
+    "Set default folder for accepted shares" : "為已接受的分享選擇一個默認資料夾",
+    "Reset" : "重設",
+    "Reset folder to system default" : "將資料夾重置為系統默認值",
+    "Share expiration: " : "共享有效期‌：",
+    "Share Expiration" : "共享有效期‌",
     "group" : "群組",
     "conversation" : "對話",
     "remote" : "遠端",
     "remote group" : "遠端群組",
     "guest" : "訪客",
+    "by {initiator}" : "由 {initiator}",
     "Shared with the group {user} by {owner}" : "由 {owner} 分享予群組 {user}",
     "Shared with the conversation {user} by {owner}" : "{owner}與{user}共享",
     "Shared with {user} by {owner}" : "{user}與{owner}共享",
+    "Open Sharing Details" : "打開分享細節",
     "Added by {initiator}" : "由{initiator}添加",
     "Via “{folder}”" : "透過 “{folder}”",
     "Unshare" : "撤回分享",
-    "Internal link" : "內部連結",
     "Cannot copy, please copy the link manually" : "無法複製，請手動複製連結",
     "Copy internal link to clipboard" : "將內部連結複製到剪貼板",
-    "Only works for users with access to this folder" : "只對可以存取此資料夾的用戶生效",
-    "Only works for users with access to this file" : "僅適用於有權存取此檔案的用戶",
+    "Only works for people with access to this folder" : "只對可以存取此資料夾的人仕生效",
+    "Only works for people with access to this file" : "只對可以存取此檔案的人仕生效",
     "Link copied" : "連結已複製",
-    "Please enter the following required information before creating the share" : "創建分享之前，請輸入以下必填信息",
-    "Password protection (enforced)" : "密碼保護（強制）",
-    "Password protection" : "密碼保護",
-    "Enter a password" : "輸入密碼",
-    "Expiration date (enforced)" : "屆滿日期（強制）",
-    "Enter a date" : "輸入日期",
-    "Create share" : "創建分享",
-    "Cancel" : "取消",
-    "Customize link" : "自訂連結",
-    "Add another link" : "加入另一個連結",
-    "Create a new share link" : "建立新分享連結",
+    "Internal link" : "內部連結",
     "{shareWith} by {initiator}" : "{initiator} 分享了 {shareWith}",
     "Shared via link by {initiator}" : "由 {initiator} 透過連結分享",
+    "File request ({label})" : "檔案請求 ({label})",
     "Mail share ({label})" : "分享郵件（{label}）",
     "Share link ({label})" : "分享連結（{label}）",
+    "Mail share" : "郵件分享",
     "Share link ({index})" : "分享連結（{index}）",
-    "Share link" : "分享連結",
+    "Create public link" : "建立公共連結",
     "Actions for \"{title}\"" : "“{title}” 的操作",
     "Copy public link of \"{title}\" to clipboard" : "將 “{title}” 的公共連結複製到剪貼板",
     "Error, please enter proper password and/or expiration date" : "錯誤，請輸入正確的密碼和/或有效期",
     "Link share created" : "創建了連結分享",
     "Error while creating the share" : "創建分享出錯",
+    "Please enter the following required information before creating the share" : "創建分享之前，請輸入以下必填信息",
+    "Password protection (enforced)" : "密碼保護（強制）",
+    "Password protection" : "密碼保護",
+    "Enter a password" : "輸入密碼",
+    "Enable link expiration (enforced)" : "啟用連結過期（已實施）",
+    "Enable link expiration" : "啟用連結過期",
+    "Enter expiration date (enforced)" : "輸入屆滿日期（已實施）",
+    "Enter expiration date" : "輸入屆滿日期",
+    "Create share" : "創建分享",
+    "Customize link" : "自訂連結",
+    "Generate QR code" : "生成 QR Code",
+    "Add another link" : "加入另一個連結",
+    "Create a new share link" : "建立新分享連結",
+    "Quick share options, the current selected is \"{selectedOption}\"" : "快速分享選項，目前已選擇 \"{selectedOption}\"",
     "View only" : "僅檢視",
     "Can edit" : "可編輯",
-    "File drop" : "檔案拖放",
-    "Search for share recipients" : "搜尋分享參與者",
-    "No recommendations. Start typing." : "沒有建議。開始輸入。",
+    "Custom permissions" : "自訂權限",
     "Resharing is not allowed" : "不允許重新分享",
     "Name or email …" : "名字或電郵地址",
     "Name, email, or Federated Cloud ID …" : "名字，電郵地址或 Federated Cloud ID …",
@@ -187,71 +245,107 @@ OC.L10N.register(
     "Guest" : "訪客",
     "Group" : "群組",
     "Email" : "電郵地址",
-    "Circle" : "社交圈子",
+    "Team" : "團隊",
     "Talk conversation" : "Talk 對話",
     "Deck board" : "Deck 面板",
     "ScienceMesh" : "ScienceMesh",
     "on {server}" : "在 {server} 上",
+    "Enter external recipients" : "輸入外部收件人",
+    "Search for internal recipients" : "搜尋內部收件人",
+    "Note from" : "備註來自",
+    "Note:" : "備註：",
+    "File drop" : "檔案拖放",
+    "Upload files to {foldername}." : "上傳檔案至 {foldername}。",
+    "By uploading files, you agree to the terms of service." : "上傳檔案即表示您同意服務條款。",
+    "View terms of service" : "檢視服務條款",
+    "Terms of service" : "服務條款",
+    "Upload files to {folder}" : "上傳檔案到 {folder}",
+    "Submit name" : "遞交名字",
+    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} 與您分享了一個資料夾。",
+    "To upload files, you need to provide your name first." : "要上傳檔案，您需要先提供您的姓名。",
+    "Name" : "名字",
+    "Enter your name" : "輸入您的名稱",
+    "Share with {userName}" : "與 {userName} 分享",
+    "Share with email {email}" : "與電郵地址 {email} 分享",
+    "Share with group" : "與群組分享",
+    "Share in conversation" : "在對話中分享",
+    "Share with {user} on remote server {server}" : "與遠端伺服器 {server} 上的 {user} 分享",
+    "Share with remote group" : "與遠端群組分享",
+    "Share with guest" : "與訪客分享",
+    "Update share" : "更新分享",
+    "Save share" : "保存分享",
+    "Read" : "讀取",
+    "Create" : "創建",
+    "Edit" : "編輯",
+    "Share" : "分享",
+    "Delete" : "移除",
+    "Password field cannot be empty" : "密碼欄位不可為空白",
+    "Replace current password" : "取代目前密碼",
+    "Failed to generate a new token" : "產生新權杖失敗",
+    "Allow upload and editing" : "允許上傳及編輯",
+    "Allow editing" : "允許編輯",
     "Upload only" : "僅上傳",
     "Advanced settings" : "進階設定",
     "Share label" : "分享標籤",
+    "Share link token" : "分享連結權杖",
+    "Set the public share link token to something easy to remember or generate a new token. It is not recommended to use a guessable token for shares which contain sensitive information." : "將公開分享連結權杖設定為容易記住的權杖，或產生新的權杖。不建議對包含敏感資訊的分享使用可猜測的權杖。",
+    "Generating…" : "正在產生 …",
+    "Generate new token" : "産生新權杖",
     "Set password" : "設置密碼",
-    "Password" : "密碼",
     "Password expires {passwordExpirationTime}" : "密碼於 {passwordExpirationTime} 到期",
     "Password expired" : "密碼已過期",
-    "Set expiration date" : "設定到期日",
-    "Expiration date" : "到期日",
-    "Hide download" : "隱藏下載",
     "Video verification" : "視像驗證",
-    "Allow download" : "允許下載",
+    "Expiration date (enforced)" : "屆滿日期（強制）",
+    "Set expiration date" : "設定到期日",
+    "Hide download" : "隱藏下載",
+    "Allow download and sync" : "允許下載及同步",
     "Note to recipient" : "給接收者的訊息",
     "Enter a note for the share recipient" : "輸入分享收件人的註釋",
-    "Create" : "創建",
-    "Share" : "分享",
+    "Show files in grid view" : "以網格視圖顯示檔案",
     "Delete share" : "刪除分享",
-    "Share with {userName}" : "與 {userName} 分享",
-    "Share with group" : "與群組分享",
-    "Share in conversation" : "在對話中分享",
-    "Share with remote" : "與遠端分享",
-    "Share with remote group" : "與遠端群組分享",
-    "Share with guest" : "與訪客分享",
-    "Share with" : "分享與",
-    "Save share" : "保存分享",
-    "Update share" : "更新分享",
     "Others with access" : "其他擁有存取權限的人",
-    "No other users with access found" : "找不到其他擁有存取權限的用戶",
+    "No other accounts with access found" : "找不到其他擁有存取權限的帳戶",
     "Toggle list of others with access to this directory" : "切換有權存取此目錄的其他人的清單",
     "Toggle list of others with access to this file" : "切換有權存取此檔案的其他人的清單",
     "Unable to fetch inherited shares" : "無法獲取繼承的分享",
+    "Link shares" : "連結分享",
+    "Shares" : "分享",
+    "Use this method to share files with individuals or teams within your organization. If the recipient already has access to the share but cannot locate it, you can send them the internal share link for easy access." : "使用此方法與組織內的個人或團隊分享檔案。如果收件者已經可以存取分享但找不到，您可以將內部分享連結傳送給他們，以方便存取。",
+    "Use this method to share files with individuals or organizations outside your organization. Files and folders can be shared via public share links and email addresses. You can also share to other Nextcloud accounts hosted on different instances using their federated cloud ID." : "使用此方法與組織外的個人或組織分享檔案。檔案與資料夾可以透過公開的分享連結與電子郵件地址來分享。您也可以使用其他 Nextcloud 帳號的聯邦雲端 ID，將檔案分享給託管在不同站台上的其他 Nextcloud 帳號。",
+    "Shares that are not part of the internal or external shares. This can be shares from apps or other sources." : "不屬於內部或外部分享的分享。這可能是來自應用程式或其他來源的分享。",
+    "Share with accounts, teams, federated cloud IDs" : "與帳戶、團隊、聯邦雲端 ID 分享",
+    "Share with accounts and teams" : "與帳號及團隊分享",
+    "Email, federated cloud ID" : "電郵地址、聯邦雲端 ID",
     "Unable to load the shares list" : "無法載入分享清單",
     "Expires {relativetime}" : "有效期至 {relativetime}",
     "this share just expired." : "此分享剛過期。",
     "Shared with you by {owner}" : "{owner} 已經和您分享",
+    "Internal shares" : "內部分享",
+    "Internal shares explanation" : "內部分享說明",
+    "External shares" : "外部分享",
+    "External shares explanation" : "外部分享說明",
+    "Additional shares" : "額外分享",
+    "Additional shares explanation" : "額外分享說明",
+    "Link to a file" : "連結到一個檔案",
     "_Accept share_::_Accept shares_" : ["接受分享"],
     "Open in Files" : "在「檔案」應用程式中打開",
     "_Reject share_::_Reject shares_" : ["拒絕分享"],
     "_Restore share_::_Restore shares_" : ["還原分享"],
     "Shared" : "已分享",
-    "Shared multiple times with different people" : "與不同的人多次分享",
     "Shared by {ownerDisplayName}" : "由 {ownerDisplayName} 分享",
+    "Shared multiple times with different people" : "與不同的人多次分享",
     "Show sharing options" : "顯示分享選項",
-    "Link to a file" : "連結到一個檔案",
-    "Error creating the share: {errorMessage}" : "創建分享出錯：{errorMessage}",
-    "Error creating the share" : "創建分享出錯",
-    "Error updating the share: {errorMessage}" : "更新分享出錯：{errorMessage}",
-    "Error updating the share" : "更新分享出錯",
-    "File \"{path}\" has been unshared" : "檔案 “{path}” 已取消共享",
-    "Folder \"{path}\" has been unshared" : "資料夾 “{path}” 已取消共享",
-    "Share {propertyName} saved" : "分享 {propertyName} 已保存",
-    "Shared by" : "分享自",
-    "Shared with" : "分享給",
-    "Password created successfully" : "成功創建了密碼",
-    "Error generating password from password policy" : "從密碼策略生成密碼時出錯",
-    "Shared with you and the group {group} by {owner}" : "由 {owner} 分享給您和 {group}群組",
-    "Shared with you and {circle} by {owner}" : "{owner} 分享給您和 {circle}",
-    "Shared with you and the conversation {conversation} by {owner}" : "{owner} 分享給您和 {conversation} 對話",
-    "Shared with you in a conversation by {owner}" : "{owner} 在對話中分享給您",
-    "Shares" : "分享",
+    "Shared with others" : "與其他人分享",
+    "Create file request" : "創建檔案請求",
+    "Upload files to {foldername}" : "上傳檔案至 {foldername}",
+    "Public file share" : "公共檔案分享",
+    "Publicly shared file." : "公開分享的檔案。",
+    "No file" : "無檔案",
+    "The file shared with you will show up here" : "其它人與您分享的檔案將會顯示在此處",
+    "Public share" : "公共分享",
+    "Publicly shared files." : "公開分享的檔案。",
+    "No files" : "沒有檔案",
+    "Files and folders shared with you will show up here" : "其它人與您分享的檔案與資料夾將會顯示在此處",
     "Overview of shared files." : "已分享檔案的概覽。",
     "No shares" : "無分享",
     "Files and folders you shared or have been shared with you will show up here" : "您分享或已與您分享的檔案與資料夾將顯示在此處",
@@ -259,7 +353,6 @@ OC.L10N.register(
     "List of files that are shared with you." : "與您分享的檔案清單。",
     "Nothing shared with you yet" : "目前沒有任何與您分享的內容",
     "Files and folders others shared with you will show up here" : "其它人與您分享的檔案與資料夾將會顯示在此處",
-    "Shared with others" : "與其他人分享",
     "List of files that you shared with others." : "您與其他人分享的檔案清單。",
     "Nothing shared yet" : "目前沒有分享內容",
     "Files and folders you shared will show up here" : "您分享的檔案與資料夾將會顯示在此處",
@@ -267,6 +360,10 @@ OC.L10N.register(
     "List of files that are shared by link." : "透過連結分享的檔案清單。",
     "No shared links" : "沒有已分享的連結",
     "Files and folders you shared by link will show up here" : "您分享的檔案與資料夾連結將會顯示在此處",
+    "File requests" : "檔案請求",
+    "List of file requests." : "檔案請求清單",
+    "No file requests" : "沒有檔案請求",
+    "File requests you have created will show up here" : "您建立的檔案請求將會顯示在此處",
     "Deleted shares" : "移除分享",
     "List of shares you left." : "您已退出的分享的清單。",
     "No deleted shares" : "沒有移除的分享",
@@ -275,42 +372,59 @@ OC.L10N.register(
     "List of unapproved shares." : "未批准的分享清單。",
     "No pending shares" : "沒有待處理的分享",
     "Shares you have received but not approved will show up here" : "您收到但尚未核准的分享將會在此顯示",
+    "Error updating the share: {errorMessage}" : "更新分享出錯：{errorMessage}",
+    "Error updating the share" : "更新分享出錯",
+    "File \"{path}\" has been unshared" : "檔案 “{path}” 已取消共享",
+    "Folder \"{path}\" has been unshared" : "資料夾 “{path}” 已取消共享",
+    "Could not update share" : "無法更新分享",
+    "Share saved" : "已儲存分享",
+    "Share expiry date saved" : "已儲存分享過期日期",
+    "Share hide-download state saved" : "已儲存分享隱藏下載狀態",
+    "Share label saved" : "已保存分享標籤",
+    "Share note for recipient saved" : "已儲存給收件者的分享備註",
+    "Share password saved" : "已保存分享密碼",
+    "Share permissions saved" : "已儲存分享權限",
+    "Shared by" : "分享自",
+    "Shared with" : "分享給",
+    "Password created successfully" : "成功創建了密碼",
+    "Error generating password from password policy" : "從密碼策略生成密碼時出錯",
+    "Shared with you and the group {group} by {owner}" : "由 {owner} 分享給您和 {group}群組",
+    "Shared with you and {circle} by {owner}" : "{owner} 分享給您和 {circle}",
+    "Shared with you and the conversation {conversation} by {owner}" : "{owner} 分享給您和 {conversation} 對話",
+    "Shared with you in a conversation by {owner}" : "{owner} 在對話中分享給您",
     "Share note" : "分享筆記",
+    "Show list view" : "顯示清單視圖",
+    "Show grid view" : "顯示網格視圖",
     "Upload files to %s" : "上傳檔案到 %s",
+    "%s shared a folder with you." : "%s 與您分享了一個資料夾。",
     "Note" : "筆記",
     "Select or drop files" : "選擇或拖曳檔案至此",
     "Uploading files" : "檔案上傳中",
     "Uploaded files:" : "已上傳的檔案：",
     "By uploading files, you agree to the %1$sterms of service%2$s." : "上傳檔案即表示您同意 %1$s服務條款%2$s。 ",
+    "Share not found" : "找不到分享",
+    "Back to %s" : "返回 %s",
     "Add to your Nextcloud" : "加入到您的 Nextcloud",
-    "Files and folders others share with you will show up here" : "與您分享的檔案與資料夾將會顯示在這裡",
-    "Files and folders you share will show up here" : "您分享的檔案與資料夾將會顯示在這裡",
-    "Files and folders you share by link will show up here" : "您分享的檔案與資料夾連結將會顯示在這裡",
-    "Shares you deleted will show up here" : "您刪除的分享會在此顯示",
-    "Shares you have received but not confirmed will show up here" : "您收到但尚未確認的分享將會在此顯示",
-    "Shares will show up here" : "分享將會在此顯示",
-    "Restore" : "回復",
-    "Something happened. Unable to restore the share." : "出了些狀況，無法還原分享。",
-    "Something happened. Unable to accept the share." : "好像有東西出錯了。無法接受分享。",
-    "Something happened. Unable to reject the share." : "好像有東西出錯了。無法拒絕分享。",
-    "No expiration date set" : "未指定到期日",
-    "Sharing %s failed because the back end does not support sciencemesh shares" : "分享 %s 失敗，因為後端不支援 Science Mesh 分享",
-    "Allow creating" : "允許創建",
-    "Allow deleting" : "允許刪除",
-    "Allow resharing" : "允許轉貼分享",
-    "Expiration date enforced" : "已設定到期日",
-    "Password protect" : "密碼防護",
-    "Science Mesh" : "Science Mesh",
-    "No entries found in this folder" : "在此資料夾中沒有任何項目",
-    "Name" : "名稱",
-    "Share time" : "分享時間",
-    "Sorry, this link does not seem to work anymore." : "抱歉，此連結已經失效",
-    "Reasons might be:" : "可能的原因：",
-    "the item was removed" : "項目已經移除",
-    "the link expired" : "連結已過期",
-    "sharing is disabled" : "分享功能已停用",
-    "For more info, please ask the person who sent this link." : "請詢問告訴您此連結的人以瞭解更多",
-    "Update" : "更新",
-    "Share with " : "分享給"
+    "Waiting…" : "正在等待……",
+    "error" : "錯誤",
+    "finished" : "已結束",
+    "This will stop your current uploads." : "這會終止目前任何的上傳。",
+    "Move or copy" : "移動或複製",
+    "You can upload into this folder" : "你可以上傳內容到此資料夾",
+    "No compatible server found at {remote}" : "沒有在 {remote} 找到相容的伺服器",
+    "Invalid server URL" : "無效的伺服器 URL",
+    "Failed to add the public link to your Nextcloud" : "無法將公開連結加入您的 Nextcloud",
+    "Files" : "檔案",
+    "Download all files" : "下載所有檔案",
+    "Search for share recipients" : "搜尋分享參與者",
+    "No recommendations. Start typing." : "沒有建議。開始輸入。",
+    "Password field can't be empty" : "密碼欄位不可為空白",
+    "Allow download" : "允許下載",
+    "Share expire date saved" : "已儲存分享過期日期",
+    "You are not allowed to edit link shares that you don't own" : "您無權編輯不屬於您的鏈接共享",
+    "_1 email address already added_::_{count} email addresses already added_" : ["已添加 {count} 個電郵地址"],
+    "_1 email address added_::_{count} email addresses added_" : ["添加了{count}個電郵地址"],
+    "Share with accounts, teams, federated cloud id" : "與帳戶、團隊、聯邦雲端ID 分享",
+    "Email, federated cloud id" : "電郵地址、聯邦雲端 ID"
 },
 "nplurals=1; plural=0;");
