@@ -104,10 +104,18 @@ OC.L10N.register(
     "Level" : "Nivel",
     "Actions" : "Acciones",
     "No apps found for your version" : "No se encontraron aplicaciones para tu versión",
+    "Group name" : "Nombre del grupo",
     "Daemon" : "Demonio",
     "Type" : "Tipo",
     "Display Name" : "Nombre a desplegar",
+    "Learn more" : "Conoce más",
+    "Confirm" : "Confirmar",
+    "Cancel" : "Cancelar",
     "Description" : "Descripción",
+    "View in store" : "Ver en la tienda",
+    "Visit website" : "Visita el sitio web",
+    "Admin documentation" : "Documentación del administrador",
+    "Developer documentation" : "Documentación del desarrollador",
     "Details" : "Detalles",
     "All" : "Todos",
     "No results" : "No hay resultados",
@@ -122,37 +130,32 @@ OC.L10N.register(
     "Request feature" : "Solicitar una funcionalidad",
     "Ask questions or discuss" : "Hacer una pregunta o comentario",
     "Rate" : "Calificar",
-    "View in store" : "Ver en la tienda",
-    "Visit website" : "Visita el sitio web",
-    "Admin documentation" : "Documentación del administrador",
-    "Developer documentation" : "Documentación del desarrollador",
     "Changelog" : "Bitácora de cambios",
+    "Google Chrome for Android" : "Google Chrome para Android",
+    "This session" : "Esta sesión",
     "Allow filesystem access" : "Permitir acceso al sistema de archivos",
     "Rename" : "Renombrar",
     "Revoke" : "Revocar",
-    "Google Chrome for Android" : "Google Chrome para Android",
-    "This session" : "Esta sesión",
     "Device" : "Dispositivo",
     "Last activity" : "Última actividad",
     "Devices & sessions" : "Dispositivos y sesiones",
     "Web, desktop and mobile clients currently logged in to your account." : "Clientes web, de escritorio y móviles han iniciado sesión en tu cuenta. ",
+    "Error while creating device token" : "Se presentó un error al crear la ficha en el dispositivo",
     "App name" : "Nombre de la aplicación",
     "Create new app password" : "Crear una nueva contraseña de aplicación",
-    "Error while creating device token" : "Se presentó un error al crear la ficha en el dispositivo",
     "Login" : "Iniciar sesión",
     "Password" : "Contraseña",
     "Server-side encryption" : "Encripción del lado del servidor",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "La encripción del lado del servidor hace posible encriptar archivos que serán cargados a este servidor. Esto trae consigo algunas limitaciónes como penalizaciones en el desemeño, asi que habilítalo sólo si es necesario. ",
     "Enable server-side encryption" : "Habilitar encripción del lado del servidor",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "No se ha cargado un módulo de encripción, por favor habilita un módulo de encripción en el menú de la aplicación. ",
+    "Select default encryption module:" : "Selecciona el modulo de encripción predeterminado:",
+    "Enable encryption" : "Habilitar encripción",
     "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Una vez que la encripción se encuentre habilitada, todos lo archivos cargados al servidor desde ese momento en tiempo, se encriptarán en el servidor. Sólo será posible deshabilitar la encripción en una fecha posterior si el modulo de encripción activo soporta esa funcionalidad y si todas las preciondiciones están satisfechas (ejem. establecer una llave de recuperación).",
     "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "La encripción por sí sola no garantiza la seguridad del sistema. Por favor consulta la documentación para mayores informes de cómo funciona la aplicación de encripción y de los casos de uso soportados. ",
     "Be aware that encryption always increases the file size." : "Por favor considera que la encripción siempre aumenta el tamaño de los archivos. ",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Siempre es una buena idea generar respaldos de tus datos, en caso de tener encripción asegúrate de respaldar las llaves de encripción junto con tus datos. ",
     "This is the final warning: Do you really want to enable encryption?" : "Esta es la advertencia final: ¿Realmente deseas habilitar la encripción?",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "No se ha cargado un módulo de encripción, por favor habilita un módulo de encripción en el menú de la aplicación. ",
-    "Select default encryption module:" : "Selecciona el modulo de encripción predeterminado:",
-    "Cancel" : "Cancelar",
-    "Confirm" : "Confirmar",
     "Submit" : "Enviar",
     "Current password" : "Contraseña actual",
     "New password" : "Nueva contraseña",
@@ -184,7 +187,6 @@ OC.L10N.register(
     "Unnamed device" : "Dispositivo sin nombre",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador, puedes hacer ajustes finos al comportamiento de compartir. Por favor consulta la documentación para más información. ",
     "Admins" : "Administradores",
-    "Group name" : "Nombre del grupo",
     "Sending…" : "Enviando...",
     "Email sent" : "Correo electrónico enviado",
     "Location" : "Ubicación",
@@ -223,18 +225,8 @@ OC.L10N.register(
     "Like our Facebook page" : "Da un Like a nuestra página de Facebook",
     "Check out our blog" : "Visita nuestro blog",
     "Subscribe to our newsletter" : "Suscribete a nuestro boletín",
-    "No user supplied" : "No se proporcionó usuario alguno",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Por favor proporciona una contraseña de recuperación de administrador; de lo contrario toda la información del usuario se perderá. ",
-    "Invalid user" : "Usuario inválido",
-    "Your username is: %s" : "Tu Usuario es: %s",
-    "Logged in user must be a subadmin" : "El usuario firmado debe ser un subadministrador ",
-    "Exclude groups from sharing" : "Evitar que los grupos compartan",
-    "These groups will still be able to receive shares, but not to initiate them." : "Estos grupos aún podrán recibir elementos compartidos, pero no los podrán iniciar.",
     "Username" : "Usuario",
     "User backend" : "Backend del usuario",
-    "Show user backend" : "Mostrar backend del usuario",
-    "Active users" : "Usuarios activos",
-    "SMTP Username" : "Usuario SMTP",
     "Follow us on Twitter" : "Síguenos en Twitter"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
