@@ -99,13 +99,11 @@ OC.L10N.register(
     "Personal info" : "Informații personale",
     "Mobile & desktop" : "Mobil și desktop",
     "Email server" : "Server de email",
-    "Security & setup warnings" : "Alerte de securitate & configurare",
     "Background jobs" : "Proces de fundal",
     "Unlimited" : "Nelimitată",
     "Verifying" : "Se verifică",
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Directorul de date și fișierele sunt probabil accesibile din Internet. Fișierul .htaccess nu este funcțional. Se recomandă puternic configurarea serverului web astfel încât directorul de date să nu mai fie accesibil astfel, sau mutați-l în afara rădăcinii documentelor a serverului web.",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Lipsesc coloane opționale din baza de date. Datorită faptului că adăugarea de coloane tabelelor mari durează mult, acestea nu au fost adăugate automat atunci când pot fi opționale. Rulând \"occ db:add-missing-columns\", aceste coloane lipsă pot fi adăugate manual în timp ce instanța este online. Odată ce aceste coloane opționale au fost adăugate, unele funcționalități pot îmbunătăți timpul de răspuns sau uzabilitatea. ",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Lipsesc indecși din baza de date. Datorită faptului că adăugarea indecșilor la tabelele mari durează mult, aceștia nu au fost adăugați automat. Rulând \"occ db:add-missing-indices\", indecși lipsă pot fi adăugați manual în timp ce instanța rulează în continuare. Odată ce indecșii au fost adăugați, interogările acelor tabele vor fi de obicei mai rapide.",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Bazei de date îi lipsesc câteva chei primare. Datorită faptului că adăugarea cheilor primare la tabelele mari durează mult, acestea nu au fost adăugate automat. Rulând \"occ db:add-missing-primary-keys\", aceste chei primare lipsă pot fi adăugate manual în timp ce instanța rulează. ",
     "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Instanța este în modul debug. Folosiți aceasta doar pentru dezvoltare și nu în producție.",
     "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Acest server nu are o conexiune funcțională la Internet. Mai multe puncte finale nu pot fi contactate. Aceasta înseamnă că unele funcționalități precum montarea unui spațiu extern de stocare, notificări despre actualizări sau instalarea aplicațiilor din sursă terță nu vor fi accesibile. De asemenea, ar putea să nu funcționeze nici accesarea fișierelor la distanță și transmiterea emailurilor de notificare .",
@@ -120,9 +118,10 @@ OC.L10N.register(
     "Profile information" : "Informații de profil",
     "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Poza de profil, numele complet, adresa de e-mail, numărul de telefon, adresa, site-ul web, Twitter, organizația, rolul, titlul, biografia și dacă profilul dvs. este activat.",
     "Nextcloud settings" : "Setări Nextcloud",
+    "Enable" : "Activare",
     "Here you can decide which group can access certain sections of the administration settings." : "Aici puteți decide ce grup poate accesa anumite secțiuni din setările de administrare.",
-    "None" : "Niciuna",
     "Unable to modify setting" : "Nu se poate modifica setarea",
+    "None" : "Niciuna",
     "Allow apps to use the Share API" : "Permite aplicațiilor să folosească API-ul de partajare",
     "Allow resharing" : "Permite repartajarea",
     "Allow sharing with groups" : "Permite partajarea cu grupuri",
@@ -139,7 +138,6 @@ OC.L10N.register(
     "Excluded groups" : "Grupuri excluse",
     "Save changes" : "Salvează modificările",
     "Remove" : "Șterge",
-    "Disable" : "Dezactivați",
     "Featured" : "Recomandată",
     "Icon" : "Pictogramă",
     "Name" : "Nume",
@@ -147,7 +145,16 @@ OC.L10N.register(
     "Level" : "Nivel",
     "Actions" : "Acțiuni",
     "No apps found for your version" : "Nu au fost găsite aplicații pentru versiunea ta",
+    "Group name" : "Numele grupului",
+    "Type" : "Tip",
+    "Learn more" : "Află mai mult",
+    "Confirm" : "Confirmă",
+    "Cancel" : "Anulare",
     "Description" : "Descriere",
+    "View in store" : "Vezi în magazin",
+    "Visit website" : "Viziteaza pagina web",
+    "Admin documentation" : "Documentație pentru administrare",
+    "Developer documentation" : "Documentație pentru dezvoltatori",
     "Details" : "Detalii",
     "All" : "Toate ",
     "No results" : "Niciun rezultat",
@@ -160,34 +167,28 @@ OC.L10N.register(
     "Report a bug" : "Raportează un defect",
     "Request feature" : "Solicitare funcționalități",
     "Ask questions or discuss" : "Puneți întrebări sau participați la discuții",
-    "View in store" : "Vezi în magazin",
-    "Visit website" : "Viziteaza pagina web",
-    "Admin documentation" : "Documentație pentru administrare",
-    "Developer documentation" : "Documentație pentru dezvoltatori",
     "Changelog" : "Listă modificări",
+    "Google Chrome for Android" : "Google Chrome for Android",
+    "This session" : "Această sesiune",
     "Device settings" : "Setările dispozitivului",
     "Allow filesystem access" : "Permite accesul la fișierele de sistem",
     "Rename" : "Redenumește",
     "Revoke" : "Revocă",
-    "Google Chrome for Android" : "Google Chrome for Android",
-    "This session" : "Această sesiune",
     "Device" : "Dispozitiv",
     "Last activity" : "Ultima activitate",
     "Devices & sessions" : "Dispozitive și sesiuni",
     "Web, desktop and mobile clients currently logged in to your account." : "Clienții web, desktop și mobil conectați în prezent la contul dvs.",
+    "Error while creating device token" : "Eroare la crearea token-ului de dispozitiv",
     "App name" : "Numele aplicației",
     "Create new app password" : "Crează o nouă parolă pentru aplicație",
-    "Error while creating device token" : "Eroare la crearea token-ului de dispozitiv",
     "Login" : "Autentificare",
     "Password" : "Parolă",
-    "Enable" : "Activare",
     "Server-side encryption" : "Criptare la nivel de server",
     "Enable server-side encryption" : "Activează criptarea pe server",
+    "Select default encryption module:" : "Selectează modulul implicit de criptare:",
+    "Enable encryption" : "Activează criptarea",
     "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Criptarea, ca unică variantă, nu garantează securitatea sistemului. Consultați documentația pentru mai multe informații despre cum funcționează aplicația de criptare și variantele de utilizare acceptate.",
     "This is the final warning: Do you really want to enable encryption?" : "Aceasta este avertizarea finală: Chiar vrei să activezi criptarea?",
-    "Select default encryption module:" : "Selectează modulul implicit de criptare:",
-    "Cancel" : "Anulare",
-    "Confirm" : "Confirmă",
     "Submit" : "Trimite",
     "Remove group" : "Înlătură grupul",
     "Current password" : "Parola curentă",
@@ -208,7 +209,6 @@ OC.L10N.register(
     "Language" : "Limba",
     "Total rows summary" : "Rezumat total rânduri",
     "Avatar" : "Avatar",
-    "Username" : "Nume utilizator",
     "Last login" : "Ultima autentificare",
     "{size} used" : "{size} folosită",
     "Done" : "Realizat",
@@ -216,13 +216,12 @@ OC.L10N.register(
     "Visibility" : "Vizibil",
     "Show last login" : "Arată ultima autentificare",
     "Send email" : "Expediază mesajul",
+    "Server error while trying to complete WebAuthn device registration" : "Eroare de server în timpul încercării de a finaliza înregistrarea dispozitivului WebAuthn",
     "Add WebAuthn device" : "Adăugați dispozitivul WebAuthn",
     "Adding your device …" : "Adăugarea dispozitivului dvs ...",
-    "Server error while trying to complete WebAuthn device registration" : "Eroare de server în timpul încercării de a finaliza înregistrarea dispozitivului WebAuthn",
     "Unnamed device" : "Dispozitiv fără nume",
     "Your browser does not support WebAuthn." : "Browserul dvs. nu acceptă WebAuthn.",
     "Admins" : "Administratori",
-    "Group name" : "Numele grupului",
     "Sending…" : "Se trimite...",
     "Email sent" : "Mesajul a fost expediat",
     "Location" : "Locație",
@@ -239,6 +238,8 @@ OC.L10N.register(
     "Updates" : "Actualizări",
     "Featured apps" : "Aplicații recomandate",
     "Hide" : "Ascunde",
+    "Disable" : "Dezactivați",
+    "Unknown" : "Necunoscut",
     "Never" : "Niciodată",
     "Do you really want to wipe your data from this device?" : "Chiar doriți să vă ștergeți datele de pe acest dispozitiv?",
     "Confirm wipe" : "Confirmați ștergerea",
@@ -246,6 +247,7 @@ OC.L10N.register(
     "Error while updating device token name" : "Eroare la actualizarea numelui token-ului dispozitivului",
     "Error while updating device token scope" : "Eroare la actualizarea domeniului de aplicare a token-ului de dispozitiv",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Prea multe cereri din această rețea. Încercați mai târziu sau contactați administratorul.",
+    "Error" : "Eroare",
     "Forum" : "Forum",
     "Legal notice" : "Aviz juridic",
     "SSL" : "SSL",
@@ -260,44 +262,11 @@ OC.L10N.register(
     "Credentials" : "Detalii de autentificare",
     "SMTP Password" : "Parolă SMTP",
     "Save" : "Salvează",
+    "Security & setup warnings" : "Alerte de securitate & configurare",
     "All checks passed." : "Toate verificările s-au terminat fără erori.",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Această versiune comunitară a Nextcloud nu este suportată, iar notificările instantanee nu sunt disponibile.",
-    "No user supplied" : "Nu a fost furnizat niciun utilizator",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Furnizează o parolă administrativă de recuperare, altfel toate datele utilizatorilor vor fi pierdute",
-    "installing and updating apps via the App Store or Federated Cloud Sharing" : "instalarea și actualizarea aplicațiilor prin intermediul App Store sau Federated Cloud Sharing",
-    "Federated Cloud Sharing" : "Partajare federalizată cloud",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL utilizează o versiune %1$sneupdatată (%2$s). Vă rugăm să updatați sistemul de operare sau actualizați caracteristicile %3$scare nu funcționează în mod fiabil.",
-    "Invalid user" : "Utilizator invalid",
-    "Your username is: %s" : "Utilizatorul tău este: %s",
-    "Logged in user must be a subadmin" : "Utilizatorul logat trebuie să fie un subadmin",
-    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Este în așteptare o sarcină de lucru în fundal care verifică dacă există certificate SSL importate de utilizator. Vă rugăm să reveniți mai târziu.",
-    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Sunt prezente unele certificate SSL importate de utilizator, care nu mai sunt utilizate cu Nextcloud 21. Acestea pot fi importate în linia de comandă prin intermediul comenzii \"occ security:certificates:import\". Căile lor în interiorul directorului de date sunt prezentate mai jos.",
-    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Au fost găsite UUID-uri nevalabile ale utilizatorilor sau grupurilor LDAP. Vă rugăm să revizuiți setările \"Override UUID detection\" din partea Expert a configurației LDAP și să utilizați \"occ ldap:update-uuid\" pentru a le actualiza.",
-    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Autentificarea cu doi factori poate fi impusă pentru toți utilizatorii și pentru grupuri specifice. Dacă aceștia nu au configurat un furnizor cu doi factori, nu se vor putea conecta la sistem.",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "Error while deleting the token" : "Eroare de ștergere token",
-    "Use the credentials below to configure your app or device." : "Utilizați acreditările de mai jos pentru a vă configura aplicația sau dispozitivul.",
-    "For security reasons this password will only be shown once." : "Din motive de securitate, această parolă va fi afișată doar o singură dată.",
-    "Copied!" : "S-a copiat!",
-    "Copy" : "Copiază",
-    "Your email address" : "Adresa ta de email",
-    "You do not have permissions to see the details of this user" : "Nu aveți permisiuni pentru a vedea detaliile acestui utilizator",
-    "Name your device" : "Numiți dispozitivul dvs.",
-    "Add group" : "Adaugă grup",
-    "Show user backend" : "Arată administrare utilizator",
-    "Send email to new user" : "Trimite email către noul utilizator",
-    "Not saved" : "Nu a fost salvat",
-    "Twitter" : "Twitter",
-    "Show to logged in users only" : "Afișează doar pentru utilizatorii autentificați",
-    "SMTP Username" : "Nume utilizator SMTP",
-    "Set default expiration date" : "Setează data implicită de expirare",
-    "Exclude groups from sharing" : "Exclude grupuri de la partajare",
-    "These groups will still be able to receive shares, but not to initiate them." : "Aceste grupuri vor putea în continuare să primească partajări, dar nu să le inițieze."
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Lipsesc indecși din baza de date. Datorită faptului că adăugarea indecșilor la tabelele mari durează mult, aceștia nu au fost adăugați automat. Rulând \"occ db:add-missing-indices\", indecși lipsă pot fi adăugați manual în timp ce instanța rulează în continuare. Odată ce indecșii au fost adăugați, interogările acelor tabele vor fi de obicei mai rapide.",
+    "Username" : "Nume utilizator",
+    "Name your device" : "Numiți dispozitivul dvs."
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
