@@ -21,10 +21,12 @@ OC.L10N.register(
     "Undo" : "Opozovi",
     "Cancel" : "Poništi",
     "Replace" : "Zameni postojeću",
+    "Upload" : "Otpremi",
     "Edit" : "Uredi",
     "Source code" : "Izvorni kôd",
     "Done" : "Gotovo",
     "Details" : "Detalji",
+    "Choose" : "Odaberi",
     "Info" : "Info",
     "Warning" : "Upozorenje"
 },
