@@ -8,7 +8,6 @@ OC.L10N.register(
     "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Aplikace %1$s není přítomná nebo její verze není kompatibilní s tímto serverem. Zkontrolujte složku s aplikacemi. ",
     "Sample configuration detected" : "Bylo zjištěno setrvání u předváděcího nastavení",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Pravděpodobně byla zkopírována nastavení ze vzorových souborů. Toto není podporováno a může poškodit vaši instalaci. Před prováděním změn v souboru config.php si přečtěte dokumentaci",
-    "404" : "404",
     "The page could not be found on the server." : "Stránka nebyla na serveru nalezena.",
     "%s email verification" : "%s ověřování e-mailem",
     "Email verification" : "Ověřování e-mailem",
@@ -20,10 +19,11 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s a %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s a %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s a %5$s",
-    "Education Edition" : "Vydání pro vzdělávací instituce",
+    "Education bundle" : "Sada pro vzdělávání",
     "Enterprise bundle" : "Sada pro organizace",
     "Groupware bundle" : "Sada pro podporu spolupráce",
     "Hub bundle" : "Sada pro centrum aktivity (hub)",
+    "Public sector bundle" : "Balíček pro veřejný sektor",
     "Social sharing bundle" : "Balíček pro sdílení na sociálních sítích",
     "PHP %s or higher is required." : "Je vyžadováno PHP %s nebo novější.",
     "PHP with a version lower than %s is required." : "Je vyžadováno PHP ve verzi starší než %s.",
@@ -37,9 +37,10 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Jsou podporovány následující systémy: %s",
     "Server version %s or higher is required." : "Je potřeba verze serveru %s nebo novější.",
     "Server version %s or lower is required." : "Je potřeba verze serveru %s nebo starší.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Aby mohl přistupovat k tomuto nastavení je třeba, aby přihlášený uživatel byl správce, dílčí správce nebo obdržel speciální oprávnění",
-    "Logged in user must be an admin or sub admin" : "Je třeba, aby přihlášený uživatel byl správcem či správcem pro dílčí oblast",
-    "Logged in user must be an admin" : "Je třeba, aby přihlášený uživatel byl správce",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Aby mohl přistupovat k tomuto nastavení je třeba, aby přihlášený účet byl správce, dílčí správce nebo obdržel speciální oprávnění",
+    "Your current IP address doesn't allow you to perform admin actions" : "Pro IP adresu, ze které přistupujete, není umožněno provádět úkony správy",
+    "Logged in account must be an admin or sub admin" : "Je třeba, aby přihlášený účet byl správcem či správcem pro dílčí oblast",
+    "Logged in account must be an admin" : "Je třeba, aby přihlášený účet byl správcem",
     "Wiping of device %s has started" : "Vymazávání ze zařízení %s zahájeno",
     "Wiping of device »%s« has started" : "Vymazávání ze zařízení „%s“ zahájeno",
     "»%s« started remote wipe" : "„%s“ zahájilo vymazávání na dálku",
@@ -58,6 +59,11 @@ OC.L10N.register(
     "Avatar image is not square" : "Profilový obrázek není čtvercový",
     "Files" : "Soubory",
     "View profile" : "Zobrazit profil ",
+    "same time" : "stejný čas",
+    "_%nh_::_%nh_" : ["%nh","%nh","%nh","%nh"],
+    "_%nm_::_%nm_" : ["%nm","%nm","%nm","%nm"],
+    "%s ahead" : "%s před",
+    "%s behind" : "%s za",
     "Local time: %s" : "Místní čas: %s",
     "today" : "dnes",
     "tomorrow" : "zítra",
@@ -80,27 +86,49 @@ OC.L10N.register(
     "seconds ago" : "před pár sekundami",
     "Empty file" : "Prázdný soubor",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul s identifikátorem: %s neexistuje. Povolte ho v nastavení aplikací, nebo se obraťte na správce.",
+    "No file conversion providers available" : "Nejsou k dispozici žádní poskytovatelé převádění souborů",
+    "File is too large to convert" : "Soubor je příliš velký pro převod",
+    "Destination does not match conversion extension" : "Cíl neodpovídá příponě převodu",
+    "Could not convert file" : "Soubor není možné převést",
+    "Destination does not exist" : "Cíl neexistuje",
+    "Destination is not creatable" : "Cíl není možné vytvořit",
+    "Dot files are not allowed" : "Názvy souborů, začínající na tečku nejsou dovolené",
+    "%1$s (renamed)" : "%1$s (přejmenované)",
+    "renamed file" : "přejmenovaný soubor",
+    "\"%1$s\" is a forbidden file or folder name." : "„%1$s“ je zakázáno v názvu souboru nebo složky.",
+    "\"%1$s\" is a forbidden prefix for file or folder names." : "„%1$s“ je zakázaná předpona pro názvy souborů či složek.",
+    "\"%1$s\" is not allowed inside a file or folder name." : "„%1$s“ není povoleno v rámci názvu souboru či složky.",
+    "\"%1$s\" is a forbidden file type." : "„%1$s“ je nepovolený typ souboru.",
+    "Filenames must not end with \"%1$s\"." : "Je třeba, aby názvy souborů nekončily na „%1$s“.",
+    "Invalid parent path" : "Neplatný popis umístění nadřazené složky",
     "File already exists" : "Soubor už existuje",
     "Invalid path" : "Neplatný popis umístění",
     "Failed to create file from template" : "Vytvoření souboru ze šablony se nezdařilo",
     "Templates" : "Šablony",
-    "File name is a reserved word" : "Název souboru je rezervované slovo",
-    "File name contains at least one invalid character" : "Název souboru obsahuje přinejmenším jeden neplatný znak",
-    "File name is too long" : "Název souboru je příliš dlouhý",
-    "Dot files are not allowed" : "Názvy souborů, začínající na tečku nejsou dovolené",
+    "Storage %s cannot be moved" : "Úložiště %s není možné přesunout",
+    "Moving a share (%s) into a shared folder is not allowed" : "Přesunutí sdílení (%s) do sdílené složky není povoleno",
+    "Moving a storage (%s) into a shared folder is not allowed" : "Přesunutí úložiště (%s) do sdílené složky není povoleno",
+    "Moving a share (%s) into another share (%s) is not allowed" : "Přesunutí sdílení (%s) do jiného sdílení (%s) není povoleno",
+    "Moving a share (%s) into another storage (%s) is not allowed" : "Přesunutí sdílení (%s) do jiného úložiště (%s) není povoleno",
+    "Moving a storage (%s) into a share (%s) is not allowed" : "Přesunutí úložiště (%s) do sdílení (%s) není povoleno",
+    "Moving a storage (%s) into another storage (%s) is not allowed" : "Přesunutí úložiště (%s) do jiného úložiště (%s) není povoleno",
+    "Path contains invalid segments" : "Popis umístění obsahuje neplatné úseky",
+    "Filename is a reserved word" : "Název souboru je rezervované slovo",
+    "Filename contains at least one invalid character" : "Název souboru obsahuje přinejmenším jeden neplatný znak",
+    "Filename is too long" : "Název souboru je příliš dlouhý",
     "Empty filename is not allowed" : "Je třeba vyplnit název souboru",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "Aplikace „%s“ nemůže být nainstalována protože soubor appinfo nelze přečíst.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Aplikaci „%s“ nelze nainstalovat, protože není kompatibilní s touto verzí serveru.",
     "__language_name__" : "Čeština",
     "This is an automatically sent email, please do not reply." : "Toto je automaticky odesílaný e-mail, neodpovídejte na něj.",
-    "Help" : "Nápověda",
+    "Help & privacy" : "Nápověda a soukromí",
     "Appearance and accessibility" : "Vzhled a zpřístupnění",
     "Apps" : "Aplikace",
     "Personal settings" : "Osobní nastavení",
     "Administration settings" : "Nastavení pro správu",
     "Settings" : "Nastavení",
     "Log out" : "Odhlásit se",
-    "Users" : "Uživatelé",
+    "Accounts" : "Účty",
     "Email" : "E-mail",
     "Mail %s" : "Poslat e-mail %s",
     "Fediverse" : "Fediverse",
@@ -118,46 +146,83 @@ OC.L10N.register(
     "Headline" : "Nadpis",
     "Organisation" : "Organizace",
     "Role" : "Role",
-    "Unknown user" : "Neznámý uživatel",
+    "Pronouns" : "Zájmena",
+    "Unknown account" : "Neznámý účet",
     "Additional settings" : "Další nastavení",
-    "Enter the database username and name for %s" : "Zadejte uživatelské jméno v databázi a název pro %s",
-    "Enter the database username for %s" : "Zadejte uživatelské jméno v databázi pro %s",
+    "Enter the database Login and name for %s" : "Zadejte přihlašovací jméno do databáze a název pro %s",
+    "Enter the database Login for %s" : "Zadejte přihlašovací jméno pro %s",
     "Enter the database name for %s" : "Zadejte název databáze pro %s",
     "You cannot use dots in the database name %s" : "V názvu databáze %s není možné použít tečky",
-    "MySQL username and/or password not valid" : "Neplatné uživatelské jméno a/nebo heslo do MySQL",
+    "MySQL Login and/or password not valid" : "Neplatné přihlašovací jméno a/nebo heslo do MySQL",
     "You need to enter details of an existing account." : "Je třeba zadat podrobnosti existujícího účtu.",
     "Oracle connection could not be established" : "Spojení s Oracle nemohlo být navázáno",
-    "Oracle username and/or password not valid" : "Neplatné uživatelské jméno a/nebo heslo do Oracle",
-    "PostgreSQL username and/or password not valid" : "Neplatné uživatelské jméno a/nebo heslo do PostgreSQL",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "macOS není podporován a %s nebude na této platformě správně fungovat. Používejte pouze na vlastní nebezpečí!",
+    "Oracle Login and/or password not valid" : "Neplatné přihlašovací jméno a/nebo heslo do Oracle",
+    "PostgreSQL Login and/or password not valid" : "Neplatné přihlašovací jméno a/nebo heslo do PostgreSQL",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "macOS není podporován a %s nebude na této platformě správně fungovat. Používejte pouze na vlastní nebezpečí!",
     "For the best results, please consider using a GNU/Linux server instead." : "Místo toho zvažte pro nejlepší funkčnost použití GNU/Linux serveru.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Zdá se, že tato instance %s je provozována v 32-bitovém PHP prostředí a v php.ini je nastavena volba open_basedir. Toto povede k problémům se soubory většími než 4 GB a silně není doporučováno.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Odstraňte z php.ini nastavení volby open_basedir nebo přejděte na 64-bitové PHP.",
-    "Set an admin username." : "Nastavte uživatelské jméno správce.",
+    "Set an admin Login." : "Nastavte přihlašovací jméno správce.",
     "Set an admin password." : "Nastavte heslo pro účet správce.",
     "Cannot create or write into the data directory %s" : "Nedaří se vytvořit nebo zapisovat do datového adresáře %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Je třeba, aby podpůrná vrstva pro sdílení %s implementovala  rozhraní OCP\\Share_Backend",
-    "Sharing backend %s not found" : "Úložiště sdílení %s nenalezeno",
+    "Sharing backend %s not found" : "Podpůrná vrstva pro sdílení %s nenalezena",
     "Sharing backend for %s not found" : "Úložiště sdílení pro %s nenalezeno",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s sdílí „%2$s“ a dodává:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s sdílí „%2$s“ a dodává",
-    "»%s« added a note to a file shared with you" : "„%s“ dodává poznámku k nasdílenému souboru ",
-    "Open »%s«" : "Otevřít „%s“",
+    "%1$s shared %2$s with you" : "%1$s vám nasdílel(a) %2$s",
+    "Open %s" : "Otevřít %s",
     "%1$s via %2$s" : "%1$s prostřednictvím %2$s",
+    "%1$s shared %2$s with you and wants to add:" : "%1$s vám nasdílel(a) %2$s a chce přidat:",
+    "%1$s shared %2$s with you and wants to add" : "%1$s vám nasdílel(a) %2$s a chce přidat",
+    "%s added a note to a file shared with you" : "%s přidal(a) poznámku k vám nasdílenému souboru",
+    "Passwords are enforced for link and mail shares" : "Je vynucováno použití hesel pro sdílení odkazem a e-mailem",
+    "Share recipient is not a valid user" : "Příjemce sdílení není platným uživatelem",
+    "Share recipient is not a valid group" : "Příjemce sdílení není platnou skupinou",
+    "Share recipient should be empty" : "Příjemce sdílení by neměl být vyplněn",
+    "Share recipient should not be empty" : "Je třeba vyplnit příjemce sdílení",
+    "Share recipient is not a valid circle" : "Příjemce sdílení není platný okruh",
+    "Unknown share type" : "Neznámý typ sdílení",
+    "Share initiator must be set" : "Je třeba, aby iniciátor sdílení byl vyplněn",
+    "Cannot share with yourself" : "Nedává smysl nasdílet si sami sobě",
+    "Shared path must be set" : "Je třeba zadat popis umístění sdílení",
+    "Shared path must be either a file or a folder" : "Je třeba, aby sdílené umístění byl soubor nebo složka",
+    "You cannot share your root folder" : "Svou kořenovou složku nemůžete nasdílet",
     "You are not allowed to share %s" : "Nemáte povoleno sdílet %s",
-    "Cannot increase permissions of %s" : "Nelze navýšit oprávnění  u %s",
+    "Valid permissions are required for sharing" : "Pro sdílení je třeba platných oprávnění",
+    "File shares cannot have create or delete permissions" : "U sdílení souborů nemohou být oprávnění pro vytváření či mazání",
+    "Cannot increase permissions of %s" : "Nelze povýšit oprávnění  u %s",
+    "Shares need at least read permissions" : "Sdílení potřebuje alespoň oprávnění pro čtení",
     "Files cannot be shared with delete permissions" : "Soubory nelze sdílet s oprávněními k odstranění",
     "Files cannot be shared with create permissions" : "Soubory nelze sdílet s oprávněními k vytváření",
     "Expiration date is in the past" : "Datum skončení platnosti je v minulosti",
+    "Expiration date is enforced" : "Datum skončení platnosti vynuceno",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Datum vypršení nelze nastavit na více než %n den do budoucnosti","Datum vypršení nelze nastavit na více než %n dny do budoucnosti","Datum vypršení nelze nastavit na více než %n dnů do budoucnosti","Datum vypršení nelze nastavit na více než %n dny do budoucnosti"],
     "Sharing is only allowed with group members" : "Je povoleno pouze sdílení s členy skupiny",
-    "Sharing %s failed, because this item is already shared with user %s" : "Sdílení %s se nezdařilo, protože tato položka už je sdílena s uživatelem %s",
-    "%1$s shared »%2$s« with you" : "%1$s vám sdílí „%2$s“",
-    "%1$s shared »%2$s« with you." : "%1$s vám nasdílel(a) „%2$s“.",
-    "Click the button below to open it." : "Pro otevření klikněte na tlačítko níže.",
+    "Sharing %s failed, because this item is already shared with the account %s" : "Sdílení položky %s se nezdařilo, protože ta je už s účtem %s sdílena",
+    "Group sharing is now allowed" : "Skupinové sdílení je nyní povoleno",
+    "Sharing is only allowed within your own groups" : "Sdílení je povoleno pouze se členy skupin, kterých jste členy",
+    "Path is already shared with this group" : "Umístění už je této skupině nasdíleno",
+    "Link sharing is not allowed" : "Sdílení odkazů není povoleno",
+    "Public upload is not allowed" : "Veřejné nahrávání není povoleno",
+    "You cannot share a folder that contains other shares" : "Není možné nasdílet složku, která obsahuje další sdílení",
+    "Sharing is disabled" : "Sdílení je vypnuto",
+    "Sharing is disabled for you" : "Máte zakázáno sdílet",
+    "Cannot share with the share owner" : "Nelze sdílet zpět vlastníkovi sdílení",
+    "Share does not have a full ID" : "Sdílení postrádá úplný identifikátor",
+    "Cannot change share type" : "Nelze změnit typ sdílení",
+    "Can only update recipient on user shares" : "Může pouze aktualizovat příjemce u uživatelských sdílení",
+    "Cannot enable sending the password by Talk with an empty password" : "Není možné zapnout posílání hesla prostřednictvím Talk, pokud heslo není vyplněné",
+    "Cannot enable sending the password by Talk without setting a new password" : "Není možné zapnout posílání hesla prostřednictvím Talk, když není nastaveno nové heslo",
+    "Cannot disable sending the password by Talk without setting a new password" : "Není možné vypnout posílání hesla prostřednictvím Talk, když není nastaveno nové heslo",
+    "Share provider does not support accepting" : "Poskytovatel sdílení nepodporuje přijímání",
+    "Cannot change target of link share" : "Nelze změnit cíl sdílení odkazem",
+    "Invalid share recipient" : "Neplatný příjemce sdílení",
+    "Group \"%s\" does not exist" : "Skupina „%s“ neexistuje",
     "The requested share does not exist anymore" : "Požadované sdílení už neexistuje",
+    "The requested share comes from a disabled user" : "Požadované sdílení pochází od vypnutého uživatelského účtu",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Uživatel nebyl vytvořen protože bylo dosaženo limitu počtu uživatelů. Více se dozvíte v upozorněních.",
     "Could not find category \"%s\"" : "Nedaří se nalézt kategorii „%s“",
+    "Input text" : "Zadejte text",
+    "The input text" : "Vstupní text",
     "Sunday" : "neděle",
     "Monday" : "pondělí",
     "Tuesday" : "úterý",
@@ -204,19 +269,18 @@ OC.L10N.register(
     "Nov." : "list.",
     "Dec." : "pro.",
     "A valid password must be provided" : "Je třeba zadat platné heslo",
-    "The username is already being used" : "Uživatelské jméno už je využíváno",
-    "Could not create user" : "Nepodařilo se vytvořit uživatele",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Pouze následující znaky jsou povoleny pro uživatelské jméno: „a-z“, „A-Z“, „0-9“, mezery  a „_.@-'“",
-    "A valid username must be provided" : "Je třeba zadat platné uživatelské jméno",
-    "Username contains whitespace at the beginning or at the end" : "Uživatelské jméno je chybné – na jeho začátku či konci se nachází prázdný znak (mezera, tabulátor, atp.)",
-    "Username must not consist of dots only" : "Uživatelské jméno se nemůže skládat pouze ze samých teček",
-    "Username is invalid because files already exist for this user" : "Uživatelské jméno není platné, protože protože pro tohoto uživatele už existují soubory",
-    "User disabled" : "Uživatel zakázán",
+    "The Login is already being used" : "Přihlašovací jméno u je využíváno",
+    "Could not create account" : "Účet není možné vytvořit",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Pouze následující znaky jsou povoleny pro přihlašovací jméno: „a-z“, „A-Z“, „0-9“, mezery  a „_.@-'“",
+    "A valid Login must be provided" : "Je třeba zadat platné přihlašovací jméno",
+    "Login contains whitespace at the beginning or at the end" : "Přihlašovací jméno je chybné – na jeho začátku či konci se nachází prázdný znak (mezera, tabulátor, atp.)",
+    "Login must not consist of dots only" : "Přihlašovací jméno se nemůže skládat pouze ze samých teček",
+    "Login is too long" : "Přihlašovací jméno je příliš dlouhé",
+    "Login is invalid because files already exist for this user" : "Přihlašovací jméno není platné, protože protože pro tohoto uživatele už existují soubory",
+    "Account disabled" : "Účet znepřístupněn",
     "Login canceled by app" : "Přihlášení zrušeno aplikací",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Aplikaci „%1$s“ nelze nainstalovat, protože nejsou splněny následující závislosti: %2$s",
     "a safe home for all your data" : "bezpečný domov pro všechna vaše data",
-    "File is currently busy, please try again later" : "Soubor je nyní používán, zkuste to později",
-    "Cannot download file" : "Soubor se nedaří stáhnout",
     "Application is not enabled" : "Aplikace není povolena",
     "Authentication error" : "Chyba při ověřování se",
     "Token expired. Please reload page." : "Platnost tokenu skončila. Načtěte stránku znovu.",
@@ -240,18 +304,16 @@ OC.L10N.register(
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Pro nápravu nastavte v souboru php.ini parametr <code>mbstring.func_overload</code> na <code>0</code>.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP je patrně nastaveno tak, aby odstraňovalo bloky komentářů. Toto bude mít za následek znepřístupnění mnoha důležitých aplikací.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Toto je pravděpodobně způsobeno aplikacemi pro urychlení načítání jako jsou Zend OPcache nebo eAccelerator.",
-    "PHP modules have been installed, but they are still listed as missing?" : "PHP moduly jsou nainstalovány, ale stále se tváří jako chybějící?",
+    "PHP modules have been installed, but they are still listed as missing?" : "PHP moduly jsou nainstalovány, přesto jsou uváděny jako chybějící?",
     "Please ask your server administrator to restart the web server." : "Požádejte správce serveru, který využíváte o restart webového serveru.",
     "The required %s config variable is not configured in the config.php file." : "Požadovaná proměnná nastavení %s není v souboru s nastaveními config.php nastavena.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Požádejte správce serveru, který využíváte, aby zkontroloval nastavení serveru.",
-    "PostgreSQL >= 9 required." : "Je vyžadováno PostgreSQL verze 9 a novější.",
-    "Please upgrade your database version." : "Aktualizujte verzi vámi využívané databáze.",
-    "Your data directory is readable by other users." : "Váš adresář data je čitelný ostatním uživatelům.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Změňte práva na 0770, aby obsah adresáře nemohl být vypisován ostatními uživateli.",
+    "Your data directory is readable by other people." : "Váš adresář data je čitelný ostatním lidem.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Změňte práva na 0770, aby obsah adresáře nemohl být vypisován ostatními lidmi.",
     "Your data directory must be an absolute path." : "Je třeba, aby váš adresář data byl zadán jako úplný popis umístění.",
     "Check the value of \"datadirectory\" in your configuration." : "Zkontrolujte hodnotu „datadirectory“ ve svém nastavení.",
     "Your data directory is invalid." : "Váš adresář data není platný.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Ověřte, že v kořeni datového adresáře je soubor s názvem „.ocdata“.",
+    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Ověřte, že v kořeni datového adresáře je soubor s názvem „%1$s“. Měl by obsahovat: „%2$s“",
     "Action \"%s\" not supported or implemented." : "Akce „%s“ není podporována nebo implementována.",
     "Authentication failed, wrong token or provider ID given" : "Ověření se nezdařilo, předán chybný token nebo identifikátor poskytovatele",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Pro dokončení požadavku chybí parametry. Konkrétně: „%s“",
@@ -263,18 +325,145 @@ OC.L10N.register(
     "Storage connection error. %s" : "Chyba připojení úložiště. %s",
     "Storage is temporarily not available" : "Úložiště je dočasně nedostupné",
     "Storage connection timeout. %s" : "Překročen časový limit připojování k úložišti. %s",
-    "Free prompt" : "Prompt zdarma",
-    "Generate headline" : "Vytvořit nadpis",
+    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Aby bylo možné možné povolit spuštění této kontroly je třeba zajistit, aby se webový server mohl připojit sám na sebe. Proto je třeba, aby bylo možné přeložit na IP adresu a připojit se k alespoň jedné z `trusted_domains` nebo `overwrite.cli.url`. Tento nezdar může být výsledkem neshody DNS na serveru nebo odchozího pravidla na bráně firewall.",
+    "Transcribe audio" : "Vytvořit text ze zvukové nahrávky",
+    "Transcribe the things said in an audio" : "Vytvořit zápis věcí řečených ve zvukovém záznamu",
+    "Audio input" : "Zvukový vstup",
+    "The audio to transcribe" : "Nahrávka k přepisu",
+    "Transcription" : "Přepis do textu",
+    "The transcribed text" : "Přepsaný text",
+    "Chat with an agent" : "Chatovat s agentem",
+    "Chat message" : "Zpráva v chatu",
+    "A chat message to send to the agent." : "Zpráva chatu, kterou poslat agentovi.",
+    "Confirmation" : "Potvrzení",
+    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Zda potvrdit dříve vyžádané akce: 0 (nula) pro odepření a 1 pro potvrzení.",
+    "Conversation token" : "Token konverzace",
+    "A token representing the conversation." : "Token představující konverzaci.",
+    "Generated response" : "Vygenerovaná odpověď",
+    "The response from the chat model." : "Odpověď z modelu chatu.",
+    "The new conversation token" : "Token nové konverzace",
+    "Send this along with the next interaction." : "Odeslat toto společně s příští interakcí.",
+    "Requested actions by the agent" : "Akce vyžádané agentem",
+    "Actions that the agent would like to carry out in JSON format." : "Akce které by agent rád provedl (v JSON formátu).",
+    "Context write" : "Kontextový zápis",
+    "Writes text in a given style based on the provided source material." : "Napíše text v daném stylu na základě poskytnutého zdrojového materiálu.",
+    "Writing style" : "Styl zápisu",
+    "Demonstrate a writing style that you would like to immitate" : "Předvádí styl psaní, který chcete napodobit",
+    "Source material" : "Zdrojový materiál",
+    "The content that would like to be rewritten in the new writing style" : "Obsah který by byl přepsán v novém stylu psaní",
+    "Generated text" : "Vytvořený text",
+    "The generated text with content from the source material in the given style" : "Vytvořený text s obsahem ze zdrojového materiálu v daném stylu",
+    "Emoji generator" : "Generátor emotikon",
+    "Takes text and generates a representative emoji for it." : "Vezme text a vytvoří emotikonu, která ho představuje.",
+    "The text to generate an emoji for" : "Text pro který vytvořit emotikonu",
+    "Generated emoji" : "Vytvořená emotikona",
+    "The generated emoji based on the input text" : "Emotikona vytvořená na základě vstupního textu",
+    "Generate image" : "Vytvořit obrázek",
+    "Generate an image from a text prompt" : "Vytvoření obrázku dle textového zadání",
+    "Prompt" : "Výzva",
+    "Describe the image you want to generate" : "Popište obrázek, který chcete vytvořit",
+    "Number of images" : "Počet obrázků",
+    "How many images to generate" : "Kolik obrázků vytvořit",
+    "Output images" : "Výstupní obrázky",
+    "The generated images" : "Vytvořené obrázky",
+    "Generate speech" : "Vytvořit řeč",
+    "Generate speech from a transcript" : "Vytvořit řeč z přepisu",
+    "Write transcript that you want the assistant to generate speech from" : "Napište přepis, ze kterého chcete, aby asistent vytvořil řeč",
+    "Output speech" : "Výstupní řeč",
+    "The generated speech" : "Vytvořená řeč",
+    "Free text to text prompt" : "Volný text na textový prompt",
+    "Runs an arbitrary prompt through a language model that returns a reply" : "Spouští libovolnou výzvu skrze jazykový model který vrací odpověď",
+    "Describe a task that you want the assistant to do or ask a question" : "Popište úkol který chcete aby asistent udělal nebo položte dotaz",
+    "Generated reply" : "Vygenerovaná odpověď",
+    "The generated text from the assistant" : "Text vytvořený pomocníkem",
+    "Change Tone" : "Změnit tón",
+    "Change the tone of a piece of text." : "Změnit tón kusu textu.",
+    "Write a text that you want the assistant to rewrite in another tone." : "Napište text který chcete aby asistent přepsal jiným tónem.",
+    "Desired tone" : "Požadovaný tón",
+    "In which tone should your text be rewritten?" : "Ve kterém tónu by měl být váš text přepsán?",
+    "The rewritten text in the desired tone, written by the assistant:" : "Text přepsaný v požadovaném tónu, napsaný asistentem:",
+    "Chat" : "Chat",
+    "Chat with the assistant" : "Chat s pomocníkem",
+    "System prompt" : "Systémový prompt",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Definujte pravidla a předpoklady která by měl asistent v konverzaci následovat.",
+    "Chat history" : "Historie chatu",
+    "The history of chat messages before the current message, starting with a message by the user" : "Historie zpráv v chatu před stávající zprávou, počínaje zprávou od uživatele",
+    "Response message" : "Zpráva s odpovědí",
+    "The generated response as part of the conversation" : "Vytvořená odpověď jako součást konverzace",
+    "Chat with tools" : "Chatovat s nástroji",
+    "Chat with the language model with tool calling support." : "Chatovat s jazykovým modelem, který podporuje volání nástrojů.",
+    "Tool message" : "Zpráva nástroje",
+    "The result of tool calls in the last interaction" : "Výsledek volání nástroje v poslední interakci",
+    "Available tools" : "Nástroje k dispozici",
+    "The available tools in JSON format" : "Nástroje k dispozici (v JSON formátu)",
+    "The response from the chat model" : "Odpověď z modelu chatu",
+    "Tool calls" : "Volání nástrojů",
+    "Tools call instructions from the model in JSON format" : "Instrukce volání nástroje z modelu (v JSON formátu)",
+    "Formalize text" : "Formalizovat text",
+    "Takes a text and makes it sound more formal" : "Vezme text a předělá ho aby vyzněl formálněji",
+    "Write a text that you want the assistant to formalize" : "Napište text který chcete, aby asistent formalizoval",
+    "Formalized text" : "Formalizovaný text",
+    "The formalized text" : "Formalizovaný text",
+    "Generate a headline" : "Vytvořit nadpis",
     "Generates a possible headline for a text." : "Vytvoří možný nadpis pro text.",
+    "Original text" : "Původní text",
+    "The original text to generate a headline for" : "Původní text ke kterému vytvořit nadpis",
+    "The generated headline" : "Vytvořený nadpis",
+    "Proofread" : "Provést korekturu",
+    "Proofreads a text and lists corrections" : "Provést korekturu textu a vypsat opravy",
+    "Text" : "Text",
+    "The text to proofread" : "Text ve kterém provést korekturu",
+    "Corrections" : "Opravy",
+    "The corrections that should be made in your text" : "Opravy vašeho textu by měly být hotové",
+    "Reformulate text" : "Přeformulovat text",
+    "Takes a text and reformulates it" : "Vezme text a přeformuluje ho",
+    "Write a text that you want the assistant to reformulate" : "Napište text který chcete aby asistent přeformuloval",
+    "Reformulated text" : "Přeformulovaný text",
+    "The reformulated text, written by the assistant" : "Přeformulovaný text, vytvořený pomocníkem",
+    "Simplify text" : "Zjednodušit text",
+    "Takes a text and simplifies it" : "Vezme text a zjednoduší ho",
+    "Write a text that you want the assistant to simplify" : "Napište text který chcete aby asistent zjednodušil",
+    "Simplified text" : "Zjednodušený text",
+    "The simplified text" : "Zjednodušený text",
     "Summarize" : "Stručný souhrn",
-    "Summarizes text by reducing its length without losing key information." : "Vytvoří stručný souhrn textu tím, že zkrátí jeho délku aniž by byly ztraceny klíčové informace",
+    "Summarizes a text" : "Souhrn obsahu textu",
+    "The original text to summarize" : "Původní text jehož obsah shrnout",
+    "Summary" : "Souhrn",
+    "The generated summary" : "Vytvořené shrnutí",
     "Extract topics" : "Vyzískat témata",
+    "Extracts topics from a text and outputs them separated by commas" : "Vyzíská témata z textu a vypíše je oddělované čárkami",
+    "The original text to extract topics from" : "Původní text ze kterého vyzískat témata",
+    "Topics" : "Témata",
+    "The list of extracted topics" : "Seznam extrahovaných témat",
+    "Translate" : "Překládání",
+    "Translate text from one language to another" : "Přeložit text z jednoho jazyka do jiného",
+    "Origin text" : "Původní text",
+    "The text to translate" : "Text k překladu",
+    "Origin language" : "Původní jazyk",
+    "The language of the origin text" : "Jazyk původního textu",
+    "Target language" : "Cílový jazyk",
+    "The desired language to translate the origin text in" : "Požadovaný jazyk do kterého přeložit původní text",
+    "Result" : "Výsledek",
+    "The translated text" : "Přeložený text",
+    "Free prompt" : "Prompt zdarma",
+    "Runs an arbitrary prompt through the language model." : "Spouští libovolnou výzvu skrze jazykový model.",
+    "Generate headline" : "Vytvořit nadpis",
+    "Summarizes text by reducing its length without losing key information." : "Vytvoří stručný souhrn textu tím, že zkrátí jeho délku aniž by byly ztraceny klíčové informace",
     "Extracts topics from a text and outputs them separated by commas." : "Vyzíská témata z textu a vypíše je oddělované čárkami.",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Soubory aplikace %1$s nebyly nahrazeny řádně. Ověřte, že se jedná o verzi, která je kompatibilní se serverem.",
-    "Full name" : "Celé jméno",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "Bylo dosaženo limitu počtu uživatelů a uživatel proto nebyl vytvořen. Podrobnosti viz upozornění pro vás.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Pouze následující znaky jsou povoleny pro uživatelské jméno: „a-z“, „A-Z“, „0-9“, a „_.@-'“",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Je zapotřebí verze softwarové knihovny libxml2 přinejmenším 2.7.0. Nyní je nainstalována verze %s.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Tento problém opravíte instalací novější verze knihovny libxml2 a restartem webového serveru."
+    "Education Edition" : "Vydání pro vzdělávací instituce",
+    "File name is a reserved word" : "Název souboru je rezervované slovo",
+    "File name contains at least one invalid character" : "Název souboru obsahuje přinejmenším jeden neplatný znak",
+    "File name is too long" : "Název souboru je příliš dlouhý",
+    "Users" : "Uživatelé",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s sdílí „%2$s“ a dodává:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s sdílí „%2$s“ a dodává",
+    "»%s« added a note to a file shared with you" : "„%s“ dodává poznámku k nasdílenému souboru ",
+    "Open »%s«" : "Otevřít „%s“",
+    "%1$s shared »%2$s« with you" : "%1$s vám sdílí „%2$s“",
+    "%1$s shared »%2$s« with you." : "%1$s vám nasdílel(a) „%2$s“.",
+    "Click the button below to open it." : "Pro otevření klikněte na tlačítko níže.",
+    "File is currently busy, please try again later" : "Soubor je nyní používán, zkuste to později",
+    "Cannot download file" : "Soubor se nedaří stáhnout",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Ověřte, že v kořeni datového adresáře je soubor s názvem „.ocdata“."
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
