@@ -53,6 +53,7 @@ OC.L10N.register(
     "Avatar image is not square" : "تصویر آواتار مربع نیست",
     "Files" : "پوشه‌ها",
     "View profile" : "مشاهدهٔ نمایه",
+    "_%nh_::_%nh_" : ["%nh","%nh"],
     "Local time: %s" : "Local time: %s",
     "today" : "امروز",
     "tomorrow" : "فردا",
@@ -116,7 +117,6 @@ OC.L10N.register(
     "You cannot use dots in the database name %s" : "نمی‌توانید در در نام پایگاه دادهٔ %s از نقطه استفاده کنید",
     "You need to enter details of an existing account." : "لازم است جزییات یک حساب موحود را وارد کنید.",
     "Oracle connection could not be established" : "ارتباط اراکل نمیتواند برقرار باشد.",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "مک‌اواس ۱۰ پشتیبانی نشده و %s روی این بن‌سازه درست کار نخواهد کرد. با مسئولیت خودتان استفاده کنید!",
     "For the best results, please consider using a GNU/Linux server instead." : "برای بهترین نتیجه، استفاده از یک کارساز گنو/لینوکسی را در نظر داشته باشید.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "به نظر می رسد%s که این نمونه در یک محیط PHP 32 بیتی در حال اجرا است و open_baseir در php.ini پیکربندی شده است. این مسئله به پرونده هایی با بیش از 4 گیگ منجر می شود و بسیار دلسرد می شود",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "لطفاً تنظیمات open_baseir را درون php.ini خود حذف کنید یا به PHP 64 بیتی تغییر دهید.",
@@ -244,41 +244,19 @@ OC.L10N.register(
     "Summarizes text by reducing its length without losing key information." : "Summarizes text by reducing its length without losing key information.",
     "Extracts topics from a text and outputs them separated by commas." : "Extracts topics from a text and outputs them separated by commas.",
     "Education Edition" : "نگارش آموزشی",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Logged in user must be an admin, a sub admin or gotten special right to access this setting",
-    "Logged in user must be an admin or sub admin" : "ورود به سیستم کاربر باید یک مدیر یا مدیر فرعی باشد",
-    "Logged in user must be an admin" : "ورود به سیستم کاربر باید مدیر سایت باشد",
     "File name is a reserved word" : "این نام فایل جزو کلمات رزرو می‌باشد",
     "File name contains at least one invalid character" : "نام فایل دارای حداقل یک کاراکتر نامعتبر است",
     "File name is too long" : "نام فایل خیلی بزرگ است",
-    "Help" : "راهنما",
     "Users" : "کاربران",
-    "Unknown user" : "کاربر نامعلوم",
-    "Enter the database username and name for %s" : "ورود نام و نام کاربری پایگاه داده برای %s",
-    "Enter the database username for %s" : "ورود نام کاربری پایگاه داده برای %s",
-    "MySQL username and/or password not valid" : "نام کاربری یا گذرواژهٔ مای‌سکول معتبر نیست",
-    "Oracle username and/or password not valid" : "نام کاربری و / یا رمزعبور اراکل معتبر نیست.",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL نام کاربری و / یا رمزعبور معتبر نیست.",
-    "Set an admin username." : "یک نام کاربری برای مدیر تنظیم نمایید.",
     "%1$s shared »%2$s« with you and wants to add:" : "%1$s به اشتراک گذاشته شده »%2$s« با شماست و می خواهد اضافه کند:",
     "%1$s shared »%2$s« with you and wants to add" : "%1$s به اشتراک گذاشته شده »%2$s« با شماست و می خواهد اضافه کند:",
     "»%s« added a note to a file shared with you" : "»%s« یادداشتی را به پرونده ای که با شما به اشتراک گذاشته شده است اضافه کرد",
     "Open »%s«" : "باز کن »%s«",
-    "Sharing %s failed, because this item is already shared with user %s" : "Sharing %s failed, because this item is already shared with user %s",
     "%1$s shared »%2$s« with you" : "%1$s به اشتراک گذاشته » %2$s« با شما",
     "%1$s shared »%2$s« with you." : "%1$s به اشتراک گذاشته » %2$s« با شما",
     "Click the button below to open it." : "برای باز کردن آن روی دکمه زیر کلیک کنید.",
-    "The username is already being used" : "نام‌کاربری قبلا استفاده شده است",
-    "Could not create user" : "نتواسنت کاربر را ایجاد کند",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"",
-    "A valid username must be provided" : "نام کاربری صحیح باید وارد شود",
-    "Username contains whitespace at the beginning or at the end" : "نام کاربری دارای فضای سفید در ابتدا یا انتهای آن است",
-    "Username must not consist of dots only" : "نام کاربری نباید فقط از نقاط تشکیل شده باشد",
-    "Username is invalid because files already exist for this user" : "Username is invalid because files already exist for this user",
-    "User disabled" : "کاربر از کار افتاده",
     "File is currently busy, please try again later" : "فایل در حال حاضر مشغول است، لطفا مجددا تلاش کنید",
     "Cannot download file" : "نمی‌توان پرونده را بارگرفت",
-    "Your data directory is readable by other users." : "Your data directory is readable by other users.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "لطفاً مجوزها را به 0770 تغییر دهید تا فهرست توسط سایر کاربران فهرست نشود.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "اطمینان حاصل کنید که فایلی به نام \".ocdata\" در ریشه دایرکتوری داده وجود دارد."
 },
 "nplurals=2; plural=(n > 1);");
