@@ -38,7 +38,6 @@ OC.L10N.register(
     "Server version %s or higher is required." : "Wymagana jest wersja serwera %s lub wyższa.",
     "Server version %s or lower is required." : "Wymagana jest wersja serwera %s lub niższa.",
     "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Zalogowane konto musi być administratorem, subadministratorem lub posiadać specjalne uprawnienia, aby uzyskać dostęp do tego ustawienia",
-    "Your current IP address doesn’t allow you to perform admin actions" : "Twój obecny adres IP nie pozwala na wykonywanie czynności administracyjnych",
     "Logged in account must be an admin or sub admin" : "Zalogowane konto musi być administratorem lub subadministratorem",
     "Logged in account must be an admin" : "Zalogowane konto musi być administratorem",
     "Wiping of device %s has started" : "Rozpoczęto czyszczenie urządzenia %s",
@@ -59,6 +58,7 @@ OC.L10N.register(
     "Avatar image is not square" : "Obraz awatara nie jest kwadratowy",
     "Files" : "Pliki",
     "View profile" : "Zobacz profil",
+    "_%nh_::_%nh_" : ["%nh","%nh","%nh","%ngodz."],
     "Local time: %s" : "Czas lokalny: %s",
     "today" : "dzisiaj",
     "tomorrow" : "jutro",
@@ -81,7 +81,9 @@ OC.L10N.register(
     "seconds ago" : "przed chwilą",
     "Empty file" : "Pusty plik",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Moduł o ID: %s nie istnieje. Włącz go w ustawieniach aplikacji lub skontaktuj się z administratorem.",
-    "Dot files are not allowed" : "Pliki z kropką są nie dozwolone",
+    "Dot files are not allowed" : "Pliki z kropką są niedozwolone",
+    "%1$s (renamed)" : "%1$s (zmieniona nazwa)",
+    "renamed file" : "zmieniona nazwa pliku",
     "Invalid parent path" : "Nieprawidłowa ścieżka nadrzędna",
     "File already exists" : "Plik już istnieje",
     "Invalid path" : "Niewłaściwa ścieżka",
@@ -130,7 +132,6 @@ OC.L10N.register(
     "You cannot use dots in the database name %s" : "Nie można używać kropek w nazwie bazy danych %s",
     "You need to enter details of an existing account." : "Musisz wprowadzić szczegółowe dane dla istniejącego konta.",
     "Oracle connection could not be established" : "Nie można nawiązać połączenia z bazą danych Oracle",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nie jest wspierany i %s nie będzie działać poprawnie na tej platformie. Używasz go na własne ryzyko!",
     "For the best results, please consider using a GNU/Linux server instead." : "Aby uzyskać najlepszy efekt, rozważ użycie serwera GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Wydaje się, że ta instancja %s używa PHP dla 32-bitowego środowiska, ponieważ open_basedir został tak skonfigurowany w php.ini. Doprowadzi to do problemów z plikami powyżej 4 GB i jest bardzo niezalecane.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Usuń ustawienie open_basedir w php.ini lub przełącz na PHP 64-bitowe.",
@@ -140,7 +141,12 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Zaplecze do udostępniania %s musi implementować interfejs OCP\\Share_Backend",
     "Sharing backend %s not found" : "Zaplecze %s do udostępniania nie zostało znalezione",
     "Sharing backend for %s not found" : "Zaplecze do udostępniania dla %s nie zostało znalezione",
+    "%1$s shared %2$s with you" : "%1$s udostępnił %2$s Tobie",
+    "Open %s" : "Otwórz %s",
     "%1$s via %2$s" : "%1$s przez %2$s",
+    "%1$s shared %2$s with you and wants to add:" : "%1$s udostępnił Ci %2$s i chce dodać:",
+    "%1$s shared %2$s with you and wants to add" : "%1$s udostępnił Ci %2$s i chce dodać",
+    "%s added a note to a file shared with you" : "%s dodał notatkę do pliku udostępnionego Tobie",
     "Passwords are enforced for link and mail shares" : "Hasła są wymuszane w przypadku udostępniania łączy i poczty",
     "Share recipient is not a valid user" : "Odbiorca udostępnienia nie jest prawidłowym użytkownikiem",
     "Share recipient is not a valid group" : "Odbiorca udostępnienia nie jest prawidłową grupą",
@@ -167,7 +173,6 @@ OC.L10N.register(
     "Path is already shared with this group" : "Ścieżka jest już udostępniona tej grupie",
     "Link sharing is not allowed" : "Udostępnianie odnośników jest niedozwolone",
     "Public upload is not allowed" : "Przesyłanie publiczne nie jest dozwolone",
-    "Path contains files shared with you" : "Ścieżka zawiera pliki udostępnione Tobie",
     "Sharing is disabled" : "Udostępnianie jest wyłączone",
     "Sharing is disabled for you" : "Udostępnianie jest dla Ciebie wyłączone",
     "Cannot share with the share owner" : "Nie można udostępnić właścicielowi udziału",
@@ -288,6 +293,7 @@ OC.L10N.register(
     "Transcription" : "Transkrypcja",
     "The transcribed text" : "Tekst transkrypcji",
     "Confirmation" : "Potwierdzenie",
+    "Generated response" : "Wygenerowana odpowiedź",
     "Writing style" : "Styl pisania",
     "Source material" : "Materiał źródłowy",
     "Describe the image you want to generate" : "Opisz obraz, który chcesz wygenerować",
@@ -295,9 +301,15 @@ OC.L10N.register(
     "How many images to generate" : "Ile obrazów wygenerować",
     "Output images" : "Obrazy wyjściowe",
     "The generated images" : "Wygenerowane obrazy",
+    "Change Tone" : "Zmień ton wypowiedzi",
+    "Write a text that you want the assistant to rewrite in another tone." : "Napisz tekst, który chcesz, aby asystent napisał inaczej.",
+    "Desired tone" : "Pożądany ton wypowiedzi",
+    "In which tone should your text be rewritten?" : "W jakim tonie powinien zostać napisany Twój tekst?",
+    "The rewritten text in the desired tone, written by the assistant:" : "Przepisany tekst w pożądanym tonie, napisany przez asystenta:",
     "Chat" : "Rozmowa",
     "Chat history" : "Historia rozmów",
     "Generates a possible headline for a text." : "Generuje możliwy nagłówek tekstu.",
+    "Original text" : "Tekst oryginalny",
     "Text" : "Tekst",
     "Summarize" : "Podsumuj",
     "Summary" : "Podsumowanie",
@@ -320,41 +332,19 @@ OC.L10N.register(
     "Summarizes text by reducing its length without losing key information." : "Podsumowuje tekst, zmniejszając jego długość bez utraty kluczowych informacji.",
     "Extracts topics from a text and outputs them separated by commas." : "Wyodrębnia tematy z tekstu i wyświetla je oddzielone przecinkami.",
     "Education Edition" : "Edycja edukacyjna",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Zalogowany użytkownik musi być administratorem, subadministratorem lub mieć specjalne uprawnienia dostępu do tego ustawienia",
-    "Logged in user must be an admin or sub admin" : "Zalogowany użytkownik musi być administratorem lub współadministratorem",
-    "Logged in user must be an admin" : "Zalogowany użytkownik musi być administratorem",
     "File name is a reserved word" : "Nazwa pliku jest zarezerwowana",
     "File name contains at least one invalid character" : "Nazwa pliku zawiera co najmniej jeden nieprawidłowy znak",
     "File name is too long" : "Nazwa pliku jest za długa",
-    "Help" : "Pomoc",
     "Users" : "Użytkownicy",
-    "Unknown user" : "Nieznany użytkownik",
-    "Enter the database username and name for %s" : "Podaj nazwę użytkownika i nazwę bazy danych dla %s",
-    "Enter the database username for %s" : "Podaj nazwę użytkownika bazy danych dla %s",
-    "MySQL username and/or password not valid" : "Błędna nazwa użytkownika i/lub hasło do bazy danych MySQL",
-    "Oracle username and/or password not valid" : "Zła nazwa użytkownika i/lub hasło do bazy danych Oracle",
-    "PostgreSQL username and/or password not valid" : "Zła nazwa użytkownika i/lub hasło do bazy danych PostgreSQL",
-    "Set an admin username." : "Ustaw nazwę administratora.",
     "%1$s shared »%2$s« with you and wants to add:" : "%1$s udostępnił Tobie »%2$s« i chce dodać: ",
     "%1$s shared »%2$s« with you and wants to add" : " %1$s udostępnił Tobie »%2$s« i chce dodać",
     "»%s« added a note to a file shared with you" : "»%s« dodał notatkę do udostępnionego dla Ciebie pliku",
     "Open »%s«" : "Otwórz »%s«",
-    "Sharing %s failed, because this item is already shared with user %s" : "Udostępnianie %s nie powiodło się, ponieważ element jest już udostępniony użytkownikowi %s",
     "%1$s shared »%2$s« with you" : "%1$s udostępnił Tobie »%2$s«",
     "%1$s shared »%2$s« with you." : "%1$s udostępnił Tobie »%2$s«.",
     "Click the button below to open it." : "Kliknij przycisk poniżej, aby otworzyć.",
-    "The username is already being used" : "Ta nazwa użytkownika jest już używana",
-    "Could not create user" : "Nie można utworzyć użytkownika",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "W nazwie użytkownika dozwolone są tylko następujące znaki : \"a-z\", \"A-Z\", \"0-9\", spacje i \"_.@-'\"",
-    "A valid username must be provided" : "Należy podać prawidłową nazwę użytkownika",
-    "Username contains whitespace at the beginning or at the end" : "Nazwa użytkownika zawiera spację na początku albo na końcu",
-    "Username must not consist of dots only" : "Nazwa użytkownika nie może się składać tylko z kropek",
-    "Username is invalid because files already exist for this user" : "Nazwa użytkownika jest nieprawidłowa, ponieważ pliki już istnieją dla tego użytkownika",
-    "User disabled" : "Użytkownik zablokowany",
     "File is currently busy, please try again later" : "Plik jest obecnie niedostępny, spróbuj później",
     "Cannot download file" : "Nie można pobrać pliku",
-    "Your data directory is readable by other users." : "Twój katalog danych jest widoczny dla innych użytkowników.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Zmień uprawnienia na 0770, aby katalog nie był widoczny dla innych użytkowników.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Upewnij się, że w katalogu \"data\" znajduje się plik o nazwie \".ocdata\"."
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
