@@ -346,7 +346,7 @@ EOF;
 	 * Adds a heading to the email
 	 *
 	 * @param string|bool $plainTitle Title that is used in the plain text email
-	 *   if empty the $title is used, if false none will be used
+	 *                                if empty the $title is used, if false none will be used
 	 */
 	public function addHeading(string $title, $plainTitle = ''): void {
 		if ($this->footerAdded) {
@@ -379,7 +379,7 @@ EOF;
 	 *
 	 * @param string $text Note: When $plainText falls back to this, HTML is automatically escaped in the HTML email
 	 * @param string|bool $plainText Text that is used in the plain text email
-	 *   if empty the $text is used, if false none will be used
+	 *                               if empty the $text is used, if false none will be used
 	 */
 	public function addBodyText(string $text, $plainText = ''): void {
 		if ($this->footerAdded) {
@@ -406,9 +406,9 @@ EOF;
 	 * @param string $metaInfo Note: When $plainMetaInfo falls back to this, HTML is automatically escaped in the HTML email
 	 * @param string $icon Absolute path, must be 16*16 pixels
 	 * @param string|bool $plainText Text that is used in the plain text email
-	 *   if empty or true the $text is used, if false none will be used
+	 *                               if empty or true the $text is used, if false none will be used
 	 * @param string|bool $plainMetaInfo Meta info that is used in the plain text email
-	 *   if empty or true the $metaInfo is used, if false none will be used
+	 *                                   if empty or true the $metaInfo is used, if false none will be used
 	 * @param integer $plainIndent plainIndent If > 0, Indent plainText by this amount.
 	 * @since 12.0.0
 	 */
@@ -425,7 +425,7 @@ EOF;
 		if ($plainText === '' || $plainText === true) {
 			$plainText = $text;
 			$text = htmlspecialchars($text);
-			$text = str_replace("\n", "<br/>", $text); // convert newlines to HTML breaks
+			$text = str_replace("\n", '<br/>', $text); // convert newlines to HTML breaks
 		}
 		if ($plainMetaInfo === '' || $plainMetaInfo === true) {
 			$plainMetaInfo = $metaInfo;
@@ -536,7 +536,7 @@ EOF;
 	 * @param string $text Text of button; Note: When $plainText falls back to this, HTML is automatically escaped in the HTML email
 	 * @param string $url URL of button
 	 * @param string|false $plainText Text of button in plain text version
-	 * 		if empty the $text is used, if false none will be used
+	 *                                if empty the $text is used, if false none will be used
 	 *
 	 * @since 12.0.0
 	 */
